# Open source for the paper "Investigating sentence severity with judicial open data".

## Prerequisites

To make use of the software in this repository you will need:

1. A Mac, or a Linux system.
If you have Windows with a `bash` shell, it may work too.

2. About 10GB of free disk space.

3. Download `node` and `npm` from [https://nodejs.org/](https://nodejs.org/) because most of the code is JavaScript.

4. Install node package with: `npm install latinize`.

5. SPSS, because the statistical analysis is in SPSS.


## Process

The process to download and analyse the court judgments consists of three steps:

1. The maximum sentence per offence is in the file `maximum.json`.
This file is in the repository, but you should also be able to generate an up-to-date version by downloading the 11 laws indicated in the table below.
The simplest approach is to point your browser at the URL's in the table and save the text of the law ***without the navigation*** as a plain text file in the directory `Laws`.
For example, the first few lines of the most important law in the file `Laws/Sr.txt` should look as follows:

```
Wetboek van Strafrecht
Geldend van 01-01-2020 t/m heden
124 Wetboek van Strafrecht  Wetboek van Strafrecht  Wetboek van Strafrecht Wetboek van Strafrecht  Wetboek van Strafrecht Wetboek van Strafrecht
Wet van 3 maart 1881

Wij WILLEM III, bij de gratie Gods, Koning der Nederlanden, Prins van Oranje-Nassau, Groot-Hertog van Luxemburg, enz., enz., enz.
```

File		| URL
---		| ---
`AWR.txt`	| [https://wetten.overheid.nl/BWBR0002320/](https://wetten.overheid.nl/BWBR0002320/)
`Gnw.txt`	| [https://wetten.overheid.nl/BWBR0021505/](https://wetten.overheid.nl/BWBR0021505/)
`OLW.txt`	| [https://wetten.overheid.nl/BWBR0016664/](https://wetten.overheid.nl/BWBR0016664/)
`Opw.txt`	| [https://wetten.overheid.nl/BWBR0001941/](https://wetten.overheid.nl/BWBR0001941/)
`Sr.txt`	| [https://wetten.overheid.nl/BWBR0001854/](https://wetten.overheid.nl/BWBR0001854/)
`WA.txt`	| [https://wetten.overheid.nl/BWBR0005251/](https://wetten.overheid.nl/BWBR0005251/)
`WED.txt`	| [https://wetten.overheid.nl/BWBR0002063/](https://wetten.overheid.nl/BWBR0002063/)
`WM.txt`	| [https://wetten.overheid.nl/BWBR0003245/](https://wetten.overheid.nl/BWBR0003245/)
`WVW.txt`	| [https://wetten.overheid.nl/BWBR0006622/](https://wetten.overheid.nl/BWBR0006622/)
`WvMSr.txt`	| [https://wetten.overheid.nl/BWBR0001869/](https://wetten.overheid.nl/BWBR0001869/)
`Wwm.txt`	| [https://wetten.overheid.nl/BWBR0008804/](https://wetten.overheid.nl/BWBR0008804/)

2. Execute the `bash` script `unzip.sh` to download the Open data from [http://static.rechtspraak.nl/PI/OpenDataUitspraken.zip](http://static.rechtspraak.nl/PI/OpenDataUitspraken.zip) and to unpack its contents in subdirectories `2015` ... `2020` of the current directory.
There are more than 5GB of Open Data, and the download may take a while.
Unpacking and checking the court judgments takes about an hour.
If you do not have `wget` on your system, you can use your browser to download the zip file instead.
If the script completes successfully, you can delete `OpenDataUitspraken.zip` to reclaim 5GB of space.

3. Parse the penal cases from 2015-2020 by executing the `bash` script `dataset.sh`.
The process takes about an hour and generates one file per month in the directory `Judgments`, as well as the file `spss_input.csv`.

4. Open the file `spss_input.csv` in SPSS and run the syntax file `spps_script.sps`.
This takes a few minutes and generates much output.
The results may differ slightly from the results in the accompanying paper because the courts keep adding new judgments to the Open Data set.

## Contents

We give a brief description of each file in the repository:

* `classify.js` adds the maximum sentence from `maximum.json` to the intermediate data produced by `parse_judgment.js`.

* `dataset.sh` processes all the court judgments, calling all the other programs in this repository.

* `json2csv.js` converts the JSON output from the court judgment parser into a CSV file for analysis by SPSS.

* `Judgments/*.json` are the JSON files generated by `parse_judgment.js` and `classify.js`.
These files contain the coded court judgments (see step 3 above).

* `Laws/*.txt` are the plain text of the most important laws that you can download (see step 1 above).
If you decide to use the file `maximum.json` as provided, you don't have to download the laws.

* `maximum.json` lists per law and article the maximum sentence.
The file can be regenerated, provided you have access to the plain text of the laws.

* `OpenDataUitspraken.zip` is the Open Data set that you can download (see step 2 above).

* `parse_judgment.js` is the parser that automatically extracts relevant information from the Open data.

* `parse_law.js` is the parser for the law texts at `Literature/*.txt`.
The program extracts the maximum sentences for each article in these laws.
The results are in `maximum.json`.

* `README.md` is the file you are reading now.

* `spss_input.csv` will be generated by `json2csv.js`.
It should then be input to SPSS and analysed by the `spss_script.sps` script (see step 4 above).

* `spss_script.sps` is the script that instructs SPSS to analyse the output of `parse_judgment.js`.

* `spss_output.xlsx` is the output from SPSS corresponding to the Open Data from 3 April 2021.

* `support.js` contains several JavaScript functions used by most of the JavaScript programs in this directory.

* `unzip.sh` downloads and unzips the Open data.
