// Dependencies
const support = require( './support.js' ) ;

var debug = false ;

// Normalise a list of 'wettelijke voorschriften'
// input:	[['Sr_Een','77c','77g','77h'],
// 		['Sr','141','300'],
// 		['Opw','2']]
// ouput:	[['Opw','Opw_2'],
// 		['Sr','Sr_77c','Sr_77g','Sr_77h','Sr_141','Sr_300']]
function normalise( law_with_article_list_list ) {
	var result_obj = {} ;
	law_with_article_list_list.map( law_with_article_list => {
		const law = law_with_article_list[ 0 ].replace( /([^_]*)_.*/, '$1' ) ;
		const article_list = law_with_article_list.slice( 1 ) ;
		article_list.map( item => {
			const article = item.replace( /.*_(.*)/, '$1' ).toLowerCase() ;
			const law_article = law + '_' + article ;
			if( typeof result_obj[ law ] === 'undefined' ) {
				result_obj[ law ] = [] ;
			}
			if( result_obj[ law ].indexOf( law_article ) === -1 ) {
				result_obj[ law ].push( law_article ) ;
			}
		} ) ;
	} ) ;
	const result = Object.keys( result_obj ).map( law => [ law ].concat( result_obj[ law ].sort() ) ).sort() ;
	if( debug ) {
		console.log( 'normalise( %s ) = %s', JSON.stringify( law_with_article_list_list ), JSON.stringify( result ) ) ;
	}
	return result ;
}

class Article_classification {

	// Create the object
	constructor( class_list ) {
		this.Class_list = class_list ;
	}

	// Classify the article
	Classify( law_article ) {
		const law = law_article.replace( /([^_]*)_(.*)/, '$1' ) ;
		const article = law_article.replace( /([^_]*)_(.*)/, '$2' ) ;
		const article_no = Number.parseInt( article ) ;
		if( law_article === law || isNaN( article_no ) ) {
			console.error( 'Classify invalid input %s', law_article ) ;
			// process.exit( 1 ) ;
		}
		var result = [] ;
		this.Class_list.map( class_item => {
			class_item.article_list.map( article_item => {
				if( article_item.law === law ) {
					if( typeof article_item.from !== 'undefined' && typeof article_item.to !== 'undefined' ) {
						if( article_no >= article_item.from &&  article_no <= article_item.to ) {
							result.push( class_item.id ) ;
						}
					} else if( typeof article_item.list !== 'undefined' ) {
						if( article_item.list.length === 0 || article_item.list.indexOf( article ) >= 0 ) {
							result.push( class_item.id ) ;
						}
					} else {
						console.error( 'Classify invalid item %s (input %s)', article_item, law_article ) ;
						process.exit( 1 ) ;
					}
				}
			} )
		} )
		if( result.length === 1 ) {
			return result[ 0 ] ;
		} else if( result.length > 1 ) {
			console.error( 'Classify invalid input %s', law_article ) ;
			process.exit( 1 ) ;
		} else {
			return undefined ;
		}
	}

	// Show the article list
	Show( ) {
		var result = [] ;
		this.Class_list.map( class_item => {
			class_item.article_list.map( article_item => {
				if( typeof article_item.from !== 'undefined' && typeof article_item.to !== 'undefined' ) {
					for( var i = article_item.from; i <= article_item.to; i++ ) {
						result.push( [ class_item.id, article_item.law + '_' + i  ] ) ;
					}
				} else if( typeof article_item.list !== 'undefined' ) {
					article_item.list.map( item => {
						result.push( [ class_item.id, item  ] ) ;
					} ) ;
				}
			} )
		} )
		return result ;
	}

	// Test the classifier
	Test () {
		const test_list = [
			'Sr_420bis', 'Sr_420bis',
			'Sr_326',
			'Opw_10',
			'Sr_311',
			'Sr_140',
			'Sr_420ter', 'Sr_420quater',
			'Sr_282a', 'Sr_282b',
			'Sr_138ab',
			'Sr_a',
			'Sr77'
		] ;
		return test_list.map( test => [ test, this.Classify( test ) ] ) ;
	}
}

// List the titles of the penal code
const Sr_ToC_list = [
{	id:		'Sr_Een',
	article_list:	[{ law: 'Sr', from: 1, to: 91 }],
	nl:		'Algemene bepalingen'
},
{	id:		'Sr_I',
	article_list:	[{ law: 'Sr', from: 92, to: 107 }],
	nl:		'Sr_Misdrijven tegen de veiligheid van de staat'
},
{	id:		'Sr_II',
	article_list:	[{ law: 'Sr', from: 108, to: 114 }],
	nl:		'Sr_Misdrijven tegen de koninklijke waardigheid'
},
{	id:		'Sr_III',
	article_list:	[{ law: 'Sr', from: 115, to: 120 }],
	nl:		'Misdrijven tegen hoofden van bevriende Staten en andere internationaal beschermde personen'
},
{	id:		'Sr_IV',
	article_list:	[{ law: 'Sr', from: 121, to: 130 }],
	nl:		'Misdrijven betreffende de uitoefening van staatsplichten en staatsrechten'
},
{	id:		'Sr_V',
	article_list:	[{ law: 'Sr', from: 131, to: 151 }],
	nl:		'Misdrijven tegen de openbare orde'
},
{	id:		'Sr_VI',
	article_list:	[{ law: 'Sr', from: 152, to: 156 }],
	nl:		'Tweegevecht'
},
{	id:		'Sr_VII',
	article_list:	[{ law: 'Sr', from: 157, to: 176 }],
	nl:		'Sr_Misdrijven waardoor de algemene veiligheid van personen of goederen wordt in gevaar gebracht'
},
{	id:		'Sr_VIII',
	article_list:	[{ law: 'Sr', from: 177, to: 206 }],
	nl:		'Misdrijven tegen het openbaar gezag'
},
{	id:		'Sr_IX',
	article_list:	[{ law: 'Sr', from: 207, to: 207 }],
	nl:		'Meineed'
},
{	id:		'Sr_X',
	article_list:	[{ law: 'Sr', from: 208, to: 215 }],
	nl:		'Sr_Valsheid in muntspeciën en munt- en bankbiljetten'
},
{	id:		'Sr_XI',
	article_list:	[{ law: 'Sr', from: 216, to: 224 }],
	nl:		'Sr_Valsheid in zegels en merken'
},
{	id:		'Sr_XII',
	article_list:	[{ law: 'Sr', from: 225, to: 235 }],
	nl:		'Sr_Valsheid met geschriften, gegevens en biometrische kenmerken'
},
{	id:		'Sr_XIII',
	article_list:	[{ law: 'Sr', from: 236, to: 238 }],
	nl:		'Misdrijven tegen de burgerlijke staat'
},
{	id:		'Sr_XIV',
	article_list:	[{ law: 'Sr', from: 239, to: 254 }],
	nl:		'Misdrijven tegen de zeden'
},
{	id:		'Sr_XV',
	article_list:	[{ law: 'Sr', from: 255, to: 260 }],
	nl:		'Verlating van hulpbehoevenden'
},
{	id:		'Sr_XVI',
	article_list:	[{ law: 'Sr', from: 261, to: 271 }],
	nl:		'Belediging'
},
{	id:		'Sr_XVII',
	article_list:	[{ law: 'Sr', from: 272, to: 272 }, { law: 'Sr', list: ['273', '273a', '273b', '273c', '273d', '273e']}],
	nl:		'Schending van geheimen',
},
{	id:		'Sr_XVIII',
	article_list:	[{ law: 'Sr', from: 274, to: 286 }, { law: 'Sr', list: ['273f']}],
	nl:		'Sr_Misdrijven tegen de persoonlijke vrijheid',
},
{	id:		'Sr_XIX',
	article_list:	[{ law: 'Sr', from: 287, to: 295 }],
	nl:		'Misdrijven tegen het leven gericht'
},
{	id:		'Sr_XIXA',
	article_list:	[{ law: 'Sr', from: 296, to: 296 }],
	nl:		'Afbreking van zwangerschap'
},
{	id:		'Sr_XX',
	article_list:	[{ law: 'Sr', from: 300, to: 306 }],
	nl:		'Mishandeling'
},
{	id:		'Sr_XXI',
	article_list:	[{ law: 'Sr', from: 307, to: 309 }],
	nl:		'Veroorzaken van de dood of van lichamelijk letsel door schuld'
},
{	id:		'Sr_XXII',
	article_list:	[{ law: 'Sr', from: 310, to: 316 }],
	nl:		'Diefstal en stroperij'
},
{	id:		'Sr_XXIII',
	article_list:	[{ law: 'Sr', from: 317, to: 320 }],
	nl:		'Afpersing en afdreiging'
},
{	id:		'Sr_XXIV',
	article_list:	[{ law: 'Sr', from: 321, to: 325 }],
	nl:		'Verduistering'
},
{	id:		'Sr_XXV',
	article_list:	[{ law: 'Sr', from: 326, to: 339 }],
	nl:		'Bedrog'
},
{	id:		'Sr_XXVI',
	article_list:	[{ law: 'Sr', from: 340, to: 349 }],
	nl:		'Benadeling van schuldeisers of rechthebbenden'
},
{	id:		'Sr_XXVII',
	article_list:	[{ law: 'Sr', from: 350, to: 354 }],
	nl:		'Vernieling of beschadiging'
},
{	id:		'Sr_XXVIII', article_list:	[{ law: 'Sr', from: 355, to: 380 }],
	nl:		'Ambtsmisdrijven'
},
{	id:		'Sr_XXIX',
	article_list:	[{ law: 'Sr', from: 381, to: 415 }],
	nl:		'Scheepvaart- en luchtvaartmisdrijven'
},
{	id:		'Sr_XXX',
	article_list:	[{ law: 'Sr', from: 416, to: 419 }, { law: 'Sr', list: ['420'] }],
	nl:		'Begunstiging',
},
{	id:		'Sr_XXXA',
	article_list:	[{ law: 'Sr', list: ['420bis', '420ter', '420quater', '420quinquies'] }],
	nl:		'Witwassen',
},
{	id:		'Sr_XXXI',
	article_list:	[{ law: 'Sr', from: 421, to: 423 }],
	nl:		'Financieren van terrorisme'
},
{	id:		'Sr_Derde',
	article_list:	[{ law: 'Sr', from: 424, to: 479 }],
	nl:		'Overtredingen'
},
] ;


// List the standard CBS classification.
const CBS_list = [
{
	id:		'CBS_1_1',
	nl:		'Diefstal/verduistering en inbraak',
	en:		'Theft/embezzlement and burglary',
	article_list:	[{ law: 'Sr', from: 310, to: 312 }, { law: 'Sr', from: 321, to: 325 }]
},
{	id:		'CBS_1_2',
	nl:		'Bedrog',
	en:		'Fraud',
	article_list:	[{ law: 'Sr', from: 326, to: 338 }]
},
{	id:		'CBS_1_3',
	nl:		'Valsheidsmisdrijven',
	en:		'Forgery',
	article_list:	[{ law: 'Sr', from: 208, to: 214 }, { law: 'Sr', from: 216, to: 223 }, { law: 'Sr', from: 225, to: 234 }]
},
{	id:		'CBS_1_4',
	nl:		'Heling',
	en:		'Fencing',
	article_list:	[{ law: 'Sr', list: ['416', '417', '417bis'] }]
},
{	id:		'CBS_1_5',
	nl:		'Afpersing en afdreiging',
	en:		'Extortion',
	article_list:	[{ law: 'Sr', from: 317, to: 318 }]
},
{	id:		'CBS_1_6',
	nl:		'Bankbreuk',
	en:		'Bankruptcy',
	article_list:	[{ law: 'Sr', from: 340, to: 343 }]
},
{	id:		'CBS_1_7',
	nl:		'Witwassen',
	en:		'Money laundering',
	article_list:	[{ law: 'Sr', list: ['420bis', '420ter', '420quater', '420quater.1'] }]
},
{	id:		'CBS_1_8',
	nl:		'Vermogensmisdrijf (overig)',
	en:		'Property crime (other)',
	article_list:	[{ law: 'Sr', from: 314, to: 315 }, { law: 'Sr', from: 344, to: 348 }]
},
{	id:		'CBS_2_1',
	nl:		'Vernieling en beschadiging',
	en:		'Vandalism and Damage',
	article_list:	[{ law: 'Sr', from: 350, to: 352 }]
},
{	id:		'CBS_2_2',
	nl:		'Openbare orde misdrijf',
	en:		'Crime against public order',
	article_list:	[{ law: 'Sr', from: 131, to: 136 }, { law: 'Sr', from: 138, to: 151 }]
},
{	id:		'CBS_2_3',
	nl:		'Brandstichting/ontploffing',
	en:		'Arson',
	article_list:	[{ law: 'Sr', from: 157, to: 158 }]
},
{	id:		'CBS_2_4',
	nl:		'Openbaar gezag misdrijf',
	en:		'Crime against public authority',
	article_list:	[{ law: 'Sr', from: 177, to: 182 }, { law: 'Sr', from: 184, to: 206 }]
},
{	id:		'CBS_3_1',
	nl:		'Mishandeling',
	en:		'Assault',
	article_list:	[{ law: 'Sr', from: 300, to: 306 }]
},
{	id:		'CBS_3_2',
	nl:		'Bedreiging en stalking',
	en:		'Threat and stalking',
	article_list:	[{ law: 'Sr', list: ['284a', '285', '285a', '285b'] }]
},
{	id:		'CBS_3_3',
	nl:		'Seksueel misdrijf',
	en:		'Sexual offence',
	article_list:	[{ law: 'Sr', from: 239, to: 250 }]
},
{	id:		'CBS_3_4',
	nl:		'Levensmisdrijf',
	en:		'Crime against life',
	article_list:	[{ law: 'Sr', from: 287, to: 296 }]
},
{	id:		'CBS_3_5',
	nl:		'Vrijheidsbeneming/gijzeling',
	en:		'Deprivation of libery/hostage',
	article_list:	[{ law: 'Sr', list: ['282', '282a'] }]
},
{	id:		'CBS_3_6',
	nl:		'Mensenhandel',
	en:		'Human traficking',
	article_list:	[{ law: 'Sr', list: ['273f'] }]
},
{	id:		'CBS_3_7',
	nl:		'Geweldsmisdrijf (overig)',
	en:		'Violence (other)',
	article_list:	[{ law: 'Sr', from: 274, to: 281 }, { law: 'Sr', from: 307, to: 308 }]
},
{	id:		'CBS_4',
	nl:		'Sr (overig)',
	en:		'Penal code (other)',
	article_list:	[{ law: 'Sr', from: 1, to: 92 } ]
},
{	id:		'CBS_5',
	nl:		'Verkeersmisdrijven',
	en:		'Road traffic offence',
	article_list:	[{ law: 'WVW', list: [] }]
},
{	id:		'CBS_6_1',
	nl:		'Harddrugs',
	en:		'Harddrugs',
	article_list:	[{ law: 'Opw', from: 2, to: 2 }]
},
{	id:		'CBS_6_2',
	nl:		'Softdrugs',
	en:		'Softdrugs',
	article_list:	[{ law: 'Opw', from: 3, to: 3 }]
},
{	id:		'CBS_6_3',
	nl:		'Drugs (overigen)',
	en:		'Drugs (other)',
	article_list:	[{ law: 'Opw', from: 1, to: 1 }, { law: 'Opw', from: 4, to: 15 }]
},
{
	id:		'CBS_7',
	nl:		'(Vuur)wapenmisdrijven',
	en:		'Weapons',
	article_list:	[{ law: 'Wwm', list: [] }]
}
] ;
// Instantiate the two article classifiers
const Sr_ToC = new Article_classification( Sr_ToC_list ) ;
const CBS = new Article_classification( CBS_list ) ;

// Classify a normalised list of 'wettelijke voorschriften' according to 'Titel'
// input:	['Opw','Opw_2'],
// 		['Sr','Sr_77c','Sr_77g','Sr_77h','Sr_141','Sr_300']
// output:	['Opw','Opw_2'],
// 		['Sr_Een','Sr_77c','Sr_77g','Sr_77h'],
// 		['Sr_V','Sr_141'],
//		['Sr_XX','Sr_300']
function Sr_ToC_classification( law_with_article_list_list ) {
	var result_obj = {} ;
	law_with_article_list_list.map( law_with_article_list => {
		const law = law_with_article_list[ 0 ] ;
		const article_list = law_with_article_list.slice( 1 ) ;
		article_list.map( law_article => {
			var id = Sr_ToC.Classify( law_article ) ;
			if( typeof id === 'undefined' ) {
				id = law ;
			}
			if( typeof result_obj[ id ] === 'undefined' ) {
				result_obj[ id ] = [] ;
			}
			result_obj[ id ].push( law_article ) ;
		} ) ;
	} ) ;
	const result_list = Object.keys( result_obj ).map( key => [ key ].concat( result_obj[ key ] ) ).sort() ;
	const result = result_list.length > 0 ? result_list : undefined ;
	if( debug ) {
		console.log( 'Sr_ToC_classification( %s ) = %s', JSON.stringify( law_with_article_list_list ), JSON.stringify( result ) ) ;
	}
	return result ;
}

// Classify a normalised list of 'wettelijke voorschriften' according to CBS
// input:	['Opw','Opw_2'],['Sr','Sr_77c','Sr_77g','Sr_77h','Sr_141','Sr_300']
// output:	['CBS','Gnw_1','Opw_2','Sr_141','Sr_300','Sr_77c','Sr_77g','Sr_77h'],
//		['CBS_2','Sr_141'],['CBS_2_2','Sr_141'],
//		['CBS_3','Sr_300'],['CBS_3_1','Sr_300'],
//		['CBS_4','Sr_77c','Sr_77g','Sr_77h'],['CBS_6','Opw_2'],['CBS_6_1','Opw_2'],['CBS_9','Gnw_1']
function CBS_classification( law_with_article_list_list ) {
	var result_obj = {} ;
	law_with_article_list_list.map( law_with_article_list => {
		const article_list = law_with_article_list.slice( 1 ) ;
		article_list.map( article => {
			var id = CBS.Classify( article ) ;
			if( typeof id === 'undefined' ) {
				id = 'CBS_9' ;
			}
			if( typeof result_obj[ id ] === 'undefined' ) {
				result_obj[ id ] = [] ;
			}
			result_obj[ id ].push( article ) ;
		} ) ;
	} ) ;
	const key_value_list = Object.entries( result_obj ) ;
	[ 'CBS_1', 'CBS_2','CBS_3','CBS_6' ].map( id => {
		const total_list = key_value_list.map( key_value => key_value[ 0 ].match( new RegExp( id ) ) ? key_value[ 1 ] : [] ).flat ( ) ;
		if( total_list.length !== 0 ) {
			result_obj[ id ] = total_list.sort() ;
		}
	} ) ;
	const total_list = key_value_list.map( key_value => key_value[ 1 ] ).flat ( ) ;
	if( total_list.length !== 0 ) {
		result_obj[ 'CBS' ] = total_list.sort() ;
	}
	const result_list = Object.keys( result_obj ).map( key => [ key ].concat( result_obj[ key ] ) ).sort( ) ;
	const result = result_list.length > 0 ? result_list : undefined ;
	if( debug ) {
		console.log( 'CBS_classification( %s ) = %s', JSON.stringify( law_with_article_list_list ), JSON.stringify( result ) ) ;
	}
	return result ;
}

// Lookup the maximum sentence for a normalised list of 'wettelijke voorschriften'
// input:	['CBS','Gnw_1','Opw_2','Sr_141','Sr_300','Sr_77c','Sr_77g','Sr_77h'],
//		['CBS_2','Sr_141'],['CBS_2_2','Sr_141'],
//		['CBS_3','Sr_300'],['CBS_3_1','Sr_300'],
//		['CBS_4','Sr_77c','Sr_77g','Sr_77h'],['CBS_6','Opw_2'],['CBS_6_1','Opw_2'],['CBS_9','Gnw_1']
// output:	['CBS',{soort:'gevangenisstraf',eenheid:'jaar',aantal:12}],
// 		['CBS_2',{soort:'gevangenisstraf',eenheid:'jaar',aantal:12}],
// 		['CBS_2_2',{soort:'gevangenisstraf',eenheid:'jaar',aantal:12}],
// 		['CBS_3',{soort:'gevangenisstraf',eenheid:'jaar',aantal:6}],
// 		['CBS_3_1',{soort:'gevangenisstraf',eenheid:'jaar',aantal:6}]
function lookup_maximum( max_data, law_with_article_list_list ) {
	var result = [] ;
	law_with_article_list_list.map( law_with_article_list => {
		const id = law_with_article_list[ 0 ] ;
		const article_list = law_with_article_list.slice( 1 ) ;
		const max_list = [ ] ;
		article_list.map( article => {
			const lookup_list = max_data.filter( max_item => article === max_item.Wet + '_' +  max_item.Nummer ) ;
			if( lookup_list.length > 0 && typeof lookup_list[ 0 ].Maximum !== 'undefined' ) {
				const max = Object.assign( {
					// nummer : lookup_list[ 0 ].Nummer // For debugging
				}, lookup_list[ 0 ].Maximum ) ;
				max_list.push( max ) ;
			}
		} ) ;
		const sorted_max_list = max_list.sort( ( a, b ) => support.unit2hours( a.aantal, a.eenheid ) - support.unit2hours( b.aantal, b.eenheid ) ) ;
		// case_data.Lookup_list = sorted_max_list ; // For debugging
		if( sorted_max_list.length > 0 ) {
			result.push( [ id,  sorted_max_list[ sorted_max_list.length - 1 ] ] ) ;
		}
	} ) ;
	return result ;
}

// Main function
function main() {
	var result = [] ;
	var output_filename ;
	var input_filename_list = [] ;
	var annote_filename ;
	var max_filename ;
	for( var i = 2; i < process.argv.length; i++ ) {
		const arg = process.argv[ i ] ;
		if( arg === '-d' ) {
			debug = true ;
		} else if( arg === '-a' ) {
			i++ ;
			if( i < process.argv.length ) {
				annote_filename = process.argv[ i ] ;
			}
		} else if( arg === '-m' ) {
			i++ ;
			if( i < process.argv.length ) {
				max_filename = process.argv[ i ] ;
			}
		} else if( arg === '-o' ) {
			i++ ;
			if( i < process.argv.length ) {
				output_filename = process.argv[ i ] ;
			}
		} else {
			input_filename_list.push( arg ) ;
		}
	}
	if( input_filename_list.length === 0 || typeof output_filename === 'undefined' || typeof max_filename === 'undefined' ) {
		console.error( 'usage: node %s input_file... -o output_file [-a annote_file] [-m max_file] [-d]', process.argv[ 1 ] ) ;
		process.exit( 1 ) ;
	}
	const max_data = support.read_JSON( max_filename ) ;
	const annote_data = typeof annote_filename === 'undefined' ? [] : support.read_JSON( annote_filename ) ;
	input_filename_list.map( filename => {
		const data = support.read_JSON( filename ) ;
		data.map( item => {
			const annote_list = annote_data.filter( annote_item => annote_item.ECLI === item.ECLI ) ;
			if( annote_list.length > 0 ) {
				const annote_item = annote_list[ 0 ] ;
				const extra = {
					Wettelijke_voorschriften: annote_item.Wettelijke_voorschriften,
					Beslissing: annote_item.Beslissing,
					CBS_classificatie: annote_item.CBS_classificatie
				} ;
				Object.assign( item, extra ) ;
				console.log( 'annote %s: %s', item.ECLI, JSON.stringify( extra ) ) ;
			}
			if( typeof item.Wettelijke_voorschriften !== 'undefined' ) {
				const law_with_article_list_list = normalise( item.Wettelijke_voorschriften ) ;
				item.Wettelijke_voorschriften = Sr_ToC_classification( law_with_article_list_list ) ;
				item.CBS_classificatie = CBS_classification( law_with_article_list_list ) ;
				if( typeof max_data !== 'undefined' && typeof item.CBS_classificatie !== 'undefined' ) {
					item.Maximum = lookup_maximum( max_data, item.CBS_classificatie ) ;
				}
			}
			result.push( item ) ;
		} );
	} ) ;
	support.write_JSON( output_filename, result ) ;
}

// Perform a few tests
function test( ) {
	console.log( Sr_ToC.Test().join( '\n' ) ) ;
	console.log( CBS.Test().join( '\n' ) ) ;
	console.log( Sr_ToC.Show().join( '\n' ) ) ;
	console.log( CBS.Show().join( '\n' ) ) ;
	console.log( normalise( [['Opw','2'],['Sr','Sr_77c','77g','Sr_77h','Sr_141','Sr_300'],['Gnw','1']] ) ) ;
	console.log( normalise( [['Vw']] ) ) ;
	console.log( Sr_ToC_classification( [['Vw'],['Opw','Opw_2'],['Sr','Sr_77c','Sr_77g','Sr_77h','Sr_141','Sr_300'],['Gnw','Gnw_1']] ) ) ;
	console.log( Sr_ToC_classification( [['Vw']] ) ) ;
	console.log( CBS_classification( [['Vw'],['Opw','Opw_2'],['Sr','Sr_77c','Sr_77g','Sr_77h','Sr_141','Sr_300'],['Gnw','Gnw_1']] ) ) ;
	console.log( CBS_classification( [['Vw']] ) ) ;
}

main() ;
