// Dependencies
const support = require( './support.js' ) ;

// Ensure that any string, list, date or number will render ok in Excel
function string_format( data ) {
	if( typeof data === 'undefined' ) {
		return '"-"' ;
	} else {
		return '"' + data.replace( /"/g, '""' ).replace( /\n/g, ' ' ) + '"' ;
	}
}

function list_of_string_format( data ) {
	if( typeof data === 'undefined' || data.length === 0 ) {
		return '"-"' ;
	} else {
		return '"[' + data.join( "," ).replace( /"/g, '""' ) + ']"' ;
	}
}

function list_of_list_of_string_format( data ) {
	if( typeof data === 'undefined' || data.length === 0 ) {
		return '"-"' ;
	} else {
		return '"[[' + data.map( item => item.join( ',' ).replace( /"/g, '""' ) ).join( '],[' ) + ']]"' ;
	}
}

function date_format( data ) {
	if( typeof data === 'undefined' ) {
		return '' ;
	} else {
		return data.replace( /-/g, '.' ) ;
	}
}

function number_format( data ) {
	if( typeof data === 'undefined' ) {
		return '' ;
	} else {
		return data.toString() ;
	}
}

function decision_format( data ) {
	if( typeof data === 'undefined' ) {
		return '-' ;
	} else {
		return list_of_string_format( Object.values( data ) ) ;
	}
}

function months_format( data ) {
	if( typeof data === 'undefined' ) {
		return '' ;
	} else if( data.soort === 'terbeschikkingstelling' || data.soort === 'jeugddetentie' || data.soort === 'gevangenisstraf' ) {
		if( typeof data.eenheid !== 'undefined' && typeof data.aantal !== 'undefined' ) {
			const months = ( support.unit2hours( data.aantal, data.eenheid ) * 12 ) / ( 360 * 24 ) ;
			return months.toFixed( 3 ) ;
		} else {
			return '' ;
		}
	} else {
		return '' ;
	}
}

// List of main_column_list
const main_column_list = [
	'Filename',
	'ECLI',
	'Error_list',
	'Aangevers_aantal',
	'Getuigen_aantal',
	'Slachtoffers_aantal',
	'Verdachten_aantal',
	'Bijzondere_kenmerken',
	'Datum_uitspraak',
	'Expertise_rechtbank',
	'Opsporing',
	'Expertise_verdachte',
	'Vertrouwelijkheid',
	'Terrorisme',
	'Intensiteit',
	'Gevaar',
	'Article_36e',
	'Internet',
	'Geboortejaar',
	'Geboorteland',
	'Geslacht',
	'Delicten',
	'Inhoudsindicatie',
	'Instelling',
	'Locatie',
	'Onderzoek',
	'Rechtsgebieden',
	'Recidive',
	'Taal',
	'Tools',
	'Bank',
	'Richtlijnen',
	'Vindplaatsen',
	'Wettelijke_voorschriften',
	'Wetten_titels',
	'Wetten_titels_aantal',
	'CBS_ids',
	'CBS_ids_aantal',
	'Zaaknummer',
	'Paar_ID',
	'Paar_Verschil',
	'Paar_Titel',
	'Paar_Artikel',
	'Paar_Geboortejaar',
	'Beslissing',
	'Straf_maanden',
	'Taakstraf',
	'Gedeeltelijk_vrij',
	'Geboortejaar_manual',
	'Wettelijke_voorschriften_manual',
	'Beslissing_manual',
] ;

// List of laws and titles
const law_title_column_list = [
	'Sr_Een',
	'Sr_I',
	'Sr_II',
	'Sr_III',
	'Sr_IV',
	'Sr_V',
	'Sr_VI',
	'Sr_VII',
	'Sr_VIII',
	'Sr_IX',
	'Sr_X',
	'Sr_XI',
	'Sr_XII',
	'Sr_XIII',
	'Sr_XIV',
	'Sr_XV',
	'Sr_XVI',
	'Sr_XVII',
	'Sr_XVIII',
	'Sr_XIX',
	'Sr_XIXA',
	'Sr_XX',
	'Sr_XXI',
	'Sr_XXII',
	'Sr_XXIII',
	'Sr_XXIV',
	'Sr_XXV',
	'Sr_XXVI',
	'Sr_XXVII',
	'Sr_XXVIII',
	'Sr_XXIX',
	'Sr_XXX',
	'Sr_XXXA',
	'Sr_XXXI',
	'Sr_Drie',
	'AWR',
	'Gnw',
	'OLW',
	'Opw',
	'WED',
	'WM',
	'WVW',
	'Wwm'
] ;

// List the relevant identifiers of the standard classification
const cbs_column_list = [
	'CBS',
	'CBS_1',
	'CBS_1_1',
	'CBS_1_2',
	'CBS_1_3',
	'CBS_1_5',
	'CBS_1_4',
	'CBS_1_6',
	'CBS_1_7',
	'CBS_1_8',
	'CBS_2',
	'CBS_2_1',
	'CBS_2_2',
	'CBS_2_3',
	'CBS_2_4',
	'CBS_3',
	'CBS_3_1',
	'CBS_3_2',
	'CBS_3_3',
	'CBS_3_4',
	'CBS_3_5',
	'CBS_3_6',
	'CBS_3_7',
	'CBS_4',
	'CBS_5',
	'CBS_6',
	'CBS_6_1',
	'CBS_6_2',
	'CBS_6_3',
	'CBS_7',
	'CBS_9'
] ;

// Convert json to csv
function csv_header( ) {
	const txt = main_column_list
		.concat( law_title_column_list )
		.concat( cbs_column_list )
		.concat( cbs_column_list.map( item => 'Max_' + item + '_maanden' ) )
		.join( ',' ) ;
	return txt + '\n' ;
}

// Process csv data of one row
function csv_row( json ) {
	var txt = '' ;
	json.filter( item => ( typeof item.ECLI !== 'undefined' ) ).map( item => {
		var row = [
			string_format( item.Filename ),
			string_format( item.ECLI ),
			list_of_string_format( item.Error_list ),
			number_format( item.Aangevers_aantal ),
			number_format( item.Getuigen_aantal ),
			number_format( item.Slachtoffers_aantal ),
			number_format( item.Verdachten_aantal ),
			string_format( item.Bijzondere_kenmerken ),
			date_format( item.Datum_uitspraak || item.Datum_conclusie ),
			list_of_string_format( item.Expertise_rechtbank ),
			list_of_string_format( item.Opsporing ),
			list_of_string_format( item.Expertise_verdachte ),
			list_of_string_format( item.Vertrouwelijkheid ),
			list_of_string_format( item.Terrorisme ),
			list_of_string_format( item.Intensiteit ),
			list_of_string_format( item.Gevaar ),
			list_of_string_format( item.Article_36e ),
			list_of_string_format( item.Internet ),
			number_format( item.Geboortejaar ),
			string_format( item.Geboorteland ),
			string_format( item.Geslacht ),
			list_of_string_format( item.Delicten ),
			string_format( item.Inhoudsindicatie ),
			string_format( item.Instelling ),
			string_format( item.Locatie ),
			list_of_string_format( item.Onderzoek ),
			list_of_string_format( item.Rechtsgebieden ),
			string_format( item.Recidive ),
			string_format( item.Taal ),
			list_of_string_format( item.Tools ),
			list_of_string_format( item.Bank ),
			list_of_string_format( item.Richtlijnen ),
			list_of_string_format( item.Vindplaatsen ),
			list_of_list_of_string_format( item.Wettelijke_voorschriften ),
			list_of_string_format( ( support.uniq( ( item.Wettelijke_voorschriften || [] ).map( item => item[ 0 ] ) ) ) ),
			number_format( (item.Wettelijke_voorschriften || { length: undefined } ).length ),
			list_of_string_format( ( support.uniq( ( item.CBS_classificatie || [] ).map( item => item[ 0 ] ) ) ) ),
			number_format( (item.CBS_classificatie || { length: undefined } ).length ),
			string_format( item.Zaaknummer ),
			string_format( item.Paar_ID ),
			number_format( item.Paar_Verschil ),
			number_format( item.Paar_Titel ),
			number_format( item.Paar_Artikel ),
			number_format( item.Paar_Geboortejaar ),
			decision_format( ( item.Beslissing || [ undefined ] )[ 0 ] ), // Pick the first decision in the list
			months_format( ( item.Beslissing || [ undefined ] )[ 0 ] ),
			number_format( item.Taakstraf ),
			number_format( item.Gedeeltelijk_vrij ),
			number_format( item.Geboortejaar_manual ),
			list_of_list_of_string_format( item.Wettelijke_voorschriften_manual ),
			decision_format( ( item.Beslissing_manual || [ undefined] ) [ 0 ] ) // Pick the first decision in the list
		] ;
		// Analyse the legal grounds
		if( typeof item.Wettelijke_voorschriften === 'undefined' ) {
			row = row.concat( law_title_column_list.map( item => '' ) ) ;
		} else {
			const law_list = item.Wettelijke_voorschriften.map( item => item[ 0 ] ) ;
			law_title_column_list.map( column => {
				row.push( law_list.indexOf( column ) === -1 ? 0 : 1 ) ;
			} ) ;
		}
		// Analyse the CBS identifiers
		if( typeof item.CBS_classificatie === 'undefined' ) {
			row = row.concat( cbs_column_list.map( item => '' ) ) ;
		} else {
			const id_list = item.CBS_classificatie.map( item => item[ 0 ] ) ;
			cbs_column_list.map( column => {
				row.push( id_list.indexOf( column ) === -1 ? 0 : 1 ) ;
			} ) ;
		}
		// Analyse the Maximum sentences
		if( typeof item.Maximum === 'undefined' ) {
			row = row.concat( cbs_column_list.map( item => '' ) ) ;
		} else {
			cbs_column_list.map( column => {
				const filter_list = item.Maximum.filter( id_max => id_max[ 0 ] === column ) ;
				if( filter_list.length === 1 ) {
					row.push( months_format( filter_list[ 0 ][ 1 ] ) ) ;
				} else {
					row.push( '' ) ;
				}
			} ) ;
		}
		txt += row.join( ',' ) + '\n' ;
	} ) ;
	return txt ;
}

// Main function
function main() {
	var output_filename ;
	var input_filename_list = [] ;
	for( var i = 2; i < process.argv.length; i++ ) {
		const arg = process.argv[ i ] ;
		if( arg === '-o' ) {
			i++ ;
			if( i < process.argv.length ) {
				output_filename = process.argv[ i ] ;
			}
		} else {
			input_filename_list.push( arg ) ;
		}
	}
	if( input_filename_list.length === 0 || typeof output_filename === 'undefined' ) {
		console.error( 'usage: node %s input_file... -o output_file', process.argv[ 1 ] ) ;
		process.exit( 1 ) ;
	}
	var txt = csv_header() ;
	input_filename_list.map( filename => {
		const json = support
			.read_JSON( filename )
			.filter( item => typeof item.ECLI !== 'undefined' ) ;
		txt += csv_row( json ) ;
	} ) ;
	support.write_txt( output_filename, txt ) ;
}

main() ;
