USE ALL .

OMS
	/SELECT TABLES
	/IF SUBTYPES=['Notes']
	/DESTINATION VIEWER=NO
	/TAG='redundant_notes' .

OMS
	/SELECT CHARTS
	/IF COMMANDS=['CATPCA']
	/DESTINATION VIEWER=NO
	/TAG='plots_confuse_PDF' .

COMPUTE Jaar_uitspraak = XDATE.YEAR(Datum_uitspraak) .
COMPUTE Year_sentence = 999 .
MISSING VALUES Year_sentence (999) .
VARIABLE LABELS Year_sentence "Year of sentence" .
IF( Jaar_uitspraak >= 2015 AND Jaar_uitspraak <= 2020 ) Year_sentence = Jaar_uitspraak - 2010 .
ADD VALUE LABELS Year_sentence 5 "2015" 6 "2016" 7 "2017" 8 "2018" 9 "2019" 10 "2020" .

COMPUTE Issue = 1 .
FORMATS Issue (F1.0) .
IF( Issue = 1 AND CHAR.INDEX( Rechtsgebieden, "Strafrecht" ) = 0 )					Issue = 2 .
IF( Issue = 1 AND CHAR.INDEX( ECLI, "ECLI:NL:RB" ) = 0 )						Issue = 3 .
*													unused 4-6 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "open-rechtspraak not found (fatal)" ) > 0 )			Issue = 7 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "rdf:RDF not found (fatal)" ) > 0 )				Issue = 8 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "rdf:Description not found (fatal)" ) > 0 )			Issue = 9 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "uitspraak not found (fatal)" ) > 0 )				Issue = 10 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "publication withdrawn (fatal)" ) > 0 )			Issue = 11 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "publication in English (fatal)" ) > 0 )			Issue = 12 .

IF( Issue = 1 AND CHAR.INDEX( Error_list, "law section not found (warning)" ) > 0 )			Issue = 13 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "criminality section not found (warning)" ) > 0 )		Issue = 14 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "decision section not found (warning)" ) > 0 )		Issue = 15 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "decision text not found (warning)" ) > 0 )			Issue = 16 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "inhoudsindicatie not found (warning)" ) > 0 )		Issue = 17 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "uitspraak.info not found (warning)" ) > 0 )			Issue = 18 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "section not found (warning)" ) > 0 )				Issue = 19 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "not plausible as year of birth (warning)" ) > 0 )		Issue = 20 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "not plausible as number of offenders (warning)" ) > 0 )	Issue = 21 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "not plausible as number of reporters (warning)" ) > 0 )	Issue = 22 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "not plausible as number of witnesses (warning)" ) > 0 )	Issue = 23 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "not plausible as number of victims (warning)" ) > 0 )	Issue = 24 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "contains duplicates (warning)" ) > 0 )			Issue = 25 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "is not sorted (warning)" ) > 0 )				Issue = 26 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "hours not plausible (warning)" ) > 0 )			Issue = 27 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "days not plausible (warning)" ) > 0 )			Issue = 28 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "weeks not plausible (warning)" ) > 0 )			Issue = 29 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "months not plausible (warning)" ) > 0 )			Issue = 30 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "years not plausible (warning)" ) > 0 )			Issue = 31 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "euros not plausible (warning)" ) > 0 )			Issue = 32 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "not plausible for detention (warning)" ) > 0 )		Issue = 33 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "not plausible for a fine (warning)" ) > 0 )			Issue = 34 .
IF( Issue = 1 AND CHAR.INDEX( Error_list, "non-standard case from RBROT (warning)" ) > 0 )		Issue = 35 .

ADD VALUE LABELS Issue
	1 "No issue"
	2 "Not a criminal case"
	3 "Case not handled by a district court"
	7 "open-rechtspraak not found (fatal)"
	8 "rdf:RDF not found (fatal)"
	9 "rdf:Description not found (fatal)"
	10 "uitspraak not found (fatal)"
	11 "publication withdrawn (fatal)"
	12 "publication in English (fatal)"
	13 "law section not found (warning)"
	14 "criminality section not found (warning)"
	15 "decision section not found (warning)"
	16 "decision text not found (warning)"
	17 "inhoudsindicatie not found (warning)"
	18 "uitspraak.info not found (warning)"
	19 "section not found (warning)"
	20 "not plausible as year of birth (warning)"
	21 "not plausible as number of offenders (warning)"
	22 "not plausible as number of reporters (warning)"
	23 "not plausible as number of witnesses (warning)"
	24 "not plausible as number of victims (warning)"
	25 "contains duplicates (warning)"
	26 "is not sorted (warning)"
	27 "hours not plausible (warning)"
	28 "days not plausible (warning)"
	29 "weeks not plausible (warning)"
	30 "months not plausible (warning)"
	31 "years not plausible (warning)"
	32 "euros not plausible (warning)"
	33 "not plausible for detention (warning)"
	34 "not plausible for a fine (warning)"
	35 "non-standard case from RBROT (warning)" .

CROSSTABS
	/TABLES= Issue BY Year_sentence
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW
	/COUNT ROUND CELL .

COMPUTE Is_selected = ( Issue = 1 OR Issue > 12 ) .
FORMATS Is_selected (F1.0) .
IF( Jaar_uitspraak < 2015 OR Jaar_uitspraak > 2020 )	Is_selected = 0 .
ADD VALUE LABELS Is_selected 0 "Not Selected" 1 "Selected" .
FREQUENCIES VARIABLES=Is_selected .

* Comment the next statement out for manual_automatic [DEPRECATED].
SELECT IF Is_selected .

COMPUTE Max_maanden = MAX( Max_CBS_1_maanden, Max_CBS_2_maanden, Max_CBS_3_maanden, Max_CBS_5_maanden, Max_CBS_6_maanden, Max_CBS_7_maanden, Max_CBS_9_maanden ) .

* The next statements set Max_maanden and CBS_4 so that the maxima from book one of the penal code are only included if there are no maxima from other laws .
IF( MISSING( Max_maanden ) )		Max_Maanden = Max_CBS_4_maanden .

IF( CBS_1 = 1 ) CBS_4 = 0 .
IF( CBS_2 = 1 ) CBS_4 = 0 .
IF( CBS_3 = 1 ) CBS_4 = 0 .
IF( CBS_5 = 1 ) CBS_4 = 0 .
IF( CBS_6 = 1 ) CBS_4 = 0 .
IF( CBS_7 = 1 ) CBS_4 = 0 .
IF( CBS_9 = 1 ) CBS_4 = 0 .

COMPUTE Offence_count = CBS_1 + CBS_2 + CBS_3 + CBS_4 + CBS_5 + CBS_6 + CBS_7 + CBS_9 .
VARIABLE LABELS Offence_count "Number of offences" .
FORMATS Offence_count (F1.0) .

STRING Rechtbank (A5) .
COMPUTE Rechtbank = CHAR.SUBSTR( ECLI, 9, 5) .
RECODE Rechtbank
		("RBAMS" = 1)
		("RBDHA" = 2)
		("RBGEL" = 3)
		("RBLIM" = 4)
		("RBMNE" = 5)
		("RBNHO" = 6)
		("RBNNE" = 7)
		("RBOBR" = 8)
		("RBOVE" = 9)
		("RBROT" = 10)
		("RBZWB" = 11)
	INTO District_court .
ADD VALUE LABELS District_court
		1 "RBAMS"
		2 "RBDHA"
		3 "RBGEL"
		4 "RBLIM"
		5 "RBMNE"
		6 "RBNHO"
		7 "RBNNE"
		8 "RBOBR"
		9 "RBOVE"
		10 "RBROT"
		11 "RBZWB" .
FREQUENCIES VARIABLES=Year_sentence District_court .

STRING Mode (A10) .
COMPUTE Mode = "Sample" .

COMPUTE Is_born_abroad = 999 .
MISSING VALUES Is_born_abroad (999) .
VARIABLE LABELS Is_born_abroad "Is born abroad" .
IF( Geboorteland = "Nederland" )	Is_born_abroad = 0 .
IF( Geboorteland = "buitenland" )	Is_born_abroad = 1 .
ADD VALUE LABELS Is_born_abroad 0 "Born in the Netherlands" 1 "Born abroad" .
FREQUENCIES VARIABLES=Is_born_abroad .

COMPUTE Is_female_offender = 999 .
MISSING VALUES Is_female_offender (999) .
VARIABLE LABELS Is_female_offender "Is female offender" .
IF( Geslacht = "man" )		Is_female_offender = 0 .
IF( Geslacht = "vrouw" )	Is_female_offender = 1 .
ADD VALUE LABELS Is_female_offender 0 "Male offender" 1 "Female offender" .
FREQUENCIES VARIABLES=Is_female_offender .

COMPUTE Age_at_sentencing = 999 .
MISSING VALUES Age_at_sentencing (999) .
VARIABLE LABELS Age_at_sentencing "Age at sentencing" .
FORMATS Age_at_sentencing (F2.0) .
IF( ~MISSING( Geboortejaar ) ) Age_at_sentencing = Jaar_uitspraak - Geboortejaar .
FREQUENCIES VARIABLES=Age_at_sentencing .

* Categorise the age .
COMPUTE Age_category = 999 .
MISSING VALUES Age_category (999) .
IF(				Age_at_sentencing <= 17 )	Age_category = 0 .
IF( Age_at_sentencing > 17 AND Age_at_sentencing <= 20 )	Age_category = 1 .
IF( Age_at_sentencing > 20 AND Age_at_sentencing <= 30 )	Age_category = 2 .
IF( Age_at_sentencing > 30 AND Age_at_sentencing <= 40 )	Age_category = 3 .
IF( Age_at_sentencing > 40 AND Age_at_sentencing <= 50 )	Age_category = 4 .
IF( Age_at_sentencing > 50 )					Age_category = 5 .
ADD VALUE LABELS Age_category
	0 "Age at sentencing 17 and younger"
	1 "Age at sentencing 18-20"
	2 "Age at sentencing 21-30"
	3 "Age at sentencing 31-40"
	4 "Age at sentencing 41-50"
	5 "Age at sentencing 51 and older" .
FREQUENCIES VARIABLES=Age_category .

* Dummy-code the age .
COMPUTE Age_dn_17 = Age_category = 0 .
COMPUTE Age_18_20 = Age_category = 1 .
COMPUTE Age_21_30 = Age_category = 2 .
COMPUTE Age_31_40 = Age_category = 3 .
COMPUTE Age_41_50 = Age_category = 4 .
COMPUTE Age_51_up = Age_category = 5 .
FORMATS Age_dn_17 TO Age_51_up (F1.0) .
VARIABLE LABELS Age_dn_17 "Age at sentencing 17 and younger" .
VARIABLE LABELS Age_18_20 "Age at sentencing 18-20" .
VARIABLE LABELS Age_21_30 "Age at sentencing 21-30" .
VARIABLE LABELS Age_31_40 "Age at sentencing 31-40" .
VARIABLE LABELS Age_41_50 "Age at sentencing 41-50" .
VARIABLE LABELS Age_51_up "Age at sentencing 51 and older" .
FREQUENCIES VARIABLES=Age_dn_17 TO Age_51_up .

VARIABLE LABELS Verdachten_aantal "Number of offenders" .
COMPUTE Has_cooffenders = 999 .
MISSING VALUES Has_cooffenders (999) .
VARIABLE LABELS Has_cooffenders "Has Co-offenders" .
IF( Verdachten_aantal = 1 ) Has_cooffenders = 0 .
IF( Verdachten_aantal > 1 ) Has_cooffenders = 1 .
ADD VALUE LABELS Has_cooffenders 0 "No cooffenders" 1 "With cooffenders" .
FREQUENCIES VARIABLES=Verdachten_aantal Has_cooffenders .

VARIABLE LABELS Slachtoffers_aantal "Number of victims" .
COMPUTE Has_multiple_victims = 999 .
MISSING VALUES Has_multiple_victims (999) .
VARIABLE LABELS Has_multiple_victims "Has multiple victims" .
IF( Slachtoffers_aantal = 1 ) Has_multiple_victims = 0 .
IF( Slachtoffers_aantal > 1 ) Has_multiple_victims = 1 .
ADD VALUE LABELS Has_multiple_victims 0 "One victim" 1 "Multiple victims" .
FREQUENCIES VARIABLES=Slachtoffers_aantal Has_multiple_victims .

COMPUTE Is_repeat_offender = 999 .
MISSING VALUES Is_repeat_offender (999) .
VARIABLE LABELS Is_repeat_offender "Is repeat offender" .
IF( Recidive = "Eerste keer" )	Is_repeat_offender = 0 .
IF( Recidive = "Recidive")	Is_repeat_offender = 1 .
ADD VALUE LABELS Is_repeat_offender 0 "First offender" 1 "Repeat offender" .
FREQUENCIES VARIABLES=Is_repeat_offender .

VARIABLE LABELS Year_sentence "Year sentence" .
FREQUENCIES VARIABLES=Year_sentence .

VARIABLE LABELS Vertrouwelijkheid "Confidentiality" .
COMPUTE Confidentiality = Vertrouwelijkheid ~= "-" .
FREQUENCIES VARIABLES=Vertrouwelijkheid Confidentiality /FORMAT=DFREQ .

COMPUTE Decision = 999 .
MISSING VALUES Decision (999) .
VARIABLE LABELS Decision "Decision type" .
IF( CHAR.INDEX( Beslissing, "jeugddetentie" ) > 0 )			Decision = 0 .
IF( CHAR.INDEX( Beslissing, "gedragsbeinvloedendemaatregel" ) > 0 )	Decision = 1 .
IF( CHAR.INDEX( Beslissing, "gevangenisstraf" ) > 0 )			Decision = 2 .
IF( CHAR.INDEX( Beslissing, "terbeschikkingstelling" ) > 0 )		Decision = 3 .
IF( CHAR.INDEX( Beslissing, "taakstraf" ) > 0 )				Decision = 4 .
IF( CHAR.INDEX( Beslissing, "geldboete" ) > 0 )				Decision = 5 .
IF( CHAR.INDEX( Beslissing, "vrijspraak" ) > 0 )			Decision = 6 .
IF( CHAR.INDEX( Beslissing, "admin" ) > 0 )				Decision = 7 .
ADD VALUE LABELS Decision
	0 "Youth detention"
	1 "Youth measure"
	2 "Prison"
	3 "Measure"
	4 "Community service"
	5 "Fine"
	6 "Acquittal"
	7 "Procedural" .
FREQUENCIES VARIABLES=Decision .

VARIABLE LABELS Taakstraf "Community service" .
ADD VALUE LABELS Taakstraf 0 "No community service" 1 "Community service" .
FREQUENCIES VARIABLES=Taakstraf .

* Check that the type of decision matches the Taakstraf .
CROSSTABS
	/TABLES= Taakstraf BY Decision
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW
	/COUNT ROUND CELL .

FORMATS Gedeeltelijk_vrij (F1.0) .
VARIABLE LABELS Gedeeltelijk_vrij "Partially acquitted" .
FREQUENCIES VARIABLES=Gedeeltelijk_vrij .

* Check that the type of decision matches the ages .
CROSSTABS
	/TABLES= Age_category BY Decision
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW
	/COUNT ROUND CELL .

SELECT IF ( ( Decision >= 2 OR MISSING( Decision ) ) AND ( Age_category >= 1 OR MISSING( Age_category ) ) ) .

FREQUENCIES VARIABLES=Decision .

* Check that the type of decision matches the ages .
CROSSTABS
	/TABLES= Age_category BY Decision
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW
	/COUNT ROUND CELL .

COMPUTE Has_prison_sentence = Decision <= 3 .
VARIABLE LABELS Has_prison_sentence "Has prison sentence" .
ADD VALUE LABELS Has_prison_sentence 0 "No prison sentence" 1 "Prison sentence" .
FREQUENCIES VARIABLES=Has_prison_sentence .

* Convicted_or_Aquitted is MISSING for admin cases .
RECODE Decision (0, 1, 2, 3, 4, 5 = 0 ) (6 = 1 ) (7 = 2 ) ( 999 = 999 ) INTO Convicted_or_Aquitted .
MISSING VALUES Convicted_or_Aquitted (999) .
VARIABLE LABELS Convicted_or_Aquitted "Aquitted or Convicted" .
ADD VALUE LABELS Convicted_or_Aquitted 0 "Convicted" 1 "Acquitted" 2 "Procedural" .
FREQUENCIES VARIABLES=Convicted_or_Aquitted .

VARIABLE LABELS Straf_maanden "Prison months" .
FREQUENCIES VARIABLES=Straf_maanden .

COMPUTE Ln_Straf_maanden = 999 .
MISSING VALUES Ln_Straf_maanden (999) .
FORMATS Ln_Straf_maanden (F5.3) .
VARIABLE LABELS Ln_Straf_maanden "Ln (prison months)" .
IF( Straf_maanden > 0 ) Ln_Straf_maanden = LN( Straf_maanden ) .

COMPUTE Has_Ln_Straf_maanden = 0 .
VARIABLE LABELS Has_Ln_Straf_maanden "Has Ln( Straf_maanden )" .
IF( Straf_maanden > 0 ) Has_Ln_Straf_maanden = 1 .
ADD VALUE LABELS Has_Ln_Straf_maanden 0 "Missing" 1 "Present" .

* Amsterdam has high security facilities .
* Den Haag is the home of the "Cyber kamer" .
* Rotterdam is the home of the "functioneel parket" .
COMPUTE Is_specialised_court = ( Instelling = "Rechtbank Amsterdam" OR Instelling = "Rechtbank Den Haag" OR Instelling = "Rechtbank Rotterdam" ) .
FORMATS Is_specialised_court (F1.0) .
VARIABLE LABELS Is_specialised_court "Is specialised court" .
ADD VALUE LABELS Is_specialised_court 0 "Standard court" 1 "Specialised court" .
FREQUENCIES VARIABLES=Instelling Is_specialised_court .

VARIABLE LABELS Sr_Een		"Algemene bepalingen" .
VARIABLE LABELS Sr_I		"I      Misdrijven tegen de veiligheid van de staat" .
VARIABLE LABELS Sr_II		"II     Misdrijven tegen de koninklijke waardigheid" .
VARIABLE LABELS Sr_III		"III    Misdrijven tegen hoofden van bevriende Staten en andere internationaal beschermde personen" .
VARIABLE LABELS Sr_IV		"IV     Misdrijven betreffende de uitoefening van staatsplichten en staatsrechten" .
VARIABLE LABELS Sr_V		"V      Misdrijven tegen de openbare orde" .
VARIABLE LABELS Sr_VI		"VI     Tweegevecht" .
VARIABLE LABELS Sr_VII		"VII    Misdrijven waardoor de algemene veiligheid van personen of goederen wordt in gevaar gebracht" .
VARIABLE LABELS Sr_VIII		"VIII   Misdrijven tegen het openbaar gezag" .
VARIABLE LABELS Sr_IX		"IX     Meineed" .
VARIABLE LABELS Sr_X		"X      Valsheid in muntspeciën en munt- en bankbiljetten" .
VARIABLE LABELS Sr_XI		"XI     Valsheid in zegels en merken" .
VARIABLE LABELS Sr_XII		"XII    Valsheid met geschriften, gegevens en biometrische kenmerken" .
VARIABLE LABELS Sr_XIII		"XIII   Misdrijven tegen de burgerlijke staat" .
VARIABLE LABELS Sr_XIV		"XIV    Misdrijven tegen de zeden" .
VARIABLE LABELS Sr_XV		"XV     Verlating van hulpbehoevenden" .
VARIABLE LABELS Sr_XVI		"XVI    Belediging" .
VARIABLE LABELS Sr_XVII		"XVII   Schending van geheimen" .
VARIABLE LABELS Sr_XVIII	"XVIII  Misdrijven tegen de persoonlijke vrijheid" .
VARIABLE LABELS Sr_XIX		"XIX    Misdrijven tegen het leven gericht" .
VARIABLE LABELS Sr_XIXA		"XIXA   Afbreking van zwangerschap" .
VARIABLE LABELS Sr_XX		"XX     Mishandeling" .
VARIABLE LABELS Sr_XXI		"XXI    Veroorzaken van de dood of van lichamelijk letsel door schuld" .
VARIABLE LABELS Sr_XXII		"XXII   Diefstal en stroperij" .
VARIABLE LABELS Sr_XXIII	"XXIII  Afpersing en afdreiging" .
VARIABLE LABELS Sr_XXIV		"XXIV   Verduistering" .
VARIABLE LABELS Sr_XXV		"XXV    Bedrog" .
VARIABLE LABELS Sr_XXVI		"XXVI   Benadeling van schuldeisers of rechthebbenden" .
VARIABLE LABELS Sr_XXVII	"XXVII  Vernieling of beschadiging" .
VARIABLE LABELS Sr_XXVIII	"XXVIII Ambtsmisdrijven" .
VARIABLE LABELS Sr_XXIX		"XXIX   Scheepvaart- en luchtvaartmisdrijven" .
VARIABLE LABELS Sr_XXX		"XXX    Begunstiging" .
VARIABLE LABELS Sr_XXXA		"XXXA   Witwassen" .
VARIABLE LABELS Sr_XXXI		"XXXI   Financieren van terrorisme" .
VARIABLE LABELS Sr_Drie		"Overtredingen" .
VARIABLE LABELS AWR		"Algemene wet inzake rijksbelastingen" .
VARIABLE LABELS Gnw		"Geneesmiddelenwet" .
VARIABLE LABELS OLW		"Overleveringswet" .
VARIABLE LABELS Opw		"Opiumwet" .
VARIABLE LABELS WED		"Wet op de economische delicten" .
VARIABLE LABELS WM		"Wet milieubeheer" .
VARIABLE LABELS WVW		"Wegen verkeerswet" .
VARIABLE LABELS Wwm		"Wet wapens en munitie" .

MISSING VALUES Wetten_titels ("-") .
VARIABLE LABELS Wetten_titels "Laws and titles" .
VARIABLE LABELS Wetten_titels_aantal "Number of laws and titles" .
FREQUENCIES VARIABLES=Wetten_titels_aantal .

VARIABLE LABELS CBS		"Offences (total)" .
VARIABLE LABELS CBS_1		"1   Property offence" .
VARIABLE LABELS CBS_1_1		"1.1 Theft/embezzlement and burglary" .
VARIABLE LABELS CBS_1_2		"1.2 Fraud" .
VARIABLE LABELS CBS_1_3		"1.3 Forgery" .
VARIABLE LABELS CBS_1_4		"1.4 Fencing" .
VARIABLE LABELS CBS_1_5		"1.5 Extortion" .
VARIABLE LABELS CBS_1_6		"1.6 Bankruptcy" .
VARIABLE LABELS CBS_1_7		"1.7 Money laundering" .
VARIABLE LABELS CBS_1_8		"1.8 Property crime (other)" .
VARIABLE LABELS CBS_2		"2   Public order offence" .
VARIABLE LABELS CBS_2_1		"2.1 Vandalism and Damage" .
VARIABLE LABELS CBS_2_2		"2.2 Crime against public order" .
VARIABLE LABELS CBS_2_3		"2.3 Arson" .
VARIABLE LABELS CBS_2_4		"2.4 Crime against public authority" .
VARIABLE LABELS CBS_3		"3   Violent offence" .
VARIABLE LABELS CBS_3_1		"3.1 Assault" .
VARIABLE LABELS CBS_3_2		"3.2 Threat and stalking" .
VARIABLE LABELS CBS_3_3		"3.3 Sexual offence" .
VARIABLE LABELS CBS_3_4		"3.4 Crime against life" .
VARIABLE LABELS CBS_3_5		"3.5 Deprivation of libery/hostage" .
VARIABLE LABELS CBS_3_6		"3.6 Human traficking" .
VARIABLE LABELS CBS_3_7		"3.7 Violence (other)" .
VARIABLE LABELS CBS_4		"4   Criminal offence from the penal code (other)" .
VARIABLE LABELS CBS_5		"5   Road traffic offence" .
VARIABLE LABELS CBS_6		"6   Drugs" .
VARIABLE LABELS CBS_6_1		"6.1 Harddrugs" .
VARIABLE LABELS CBS_6_2		"6.2 Softdrugs" .
VARIABLE LABELS CBS_6_3		"6.3 Drugs (other)" .
VARIABLE LABELS CBS_7		"7   Weapons" .
VARIABLE LABELS CBS_9		"9   Criminal offence (other)" .

FREQUENCIES VARIABLES = Offence_count .
FREQUENCIES VARIABLES = CBS Max_maanden .
FREQUENCIES VARIABLES = CBS_1 Max_CBS_1_maanden .
FREQUENCIES VARIABLES = CBS_2 Max_CBS_2_maanden .
FREQUENCIES VARIABLES = CBS_3 Max_CBS_3_maanden .
FREQUENCIES VARIABLES = CBS_4 Max_CBS_4_maanden .
FREQUENCIES VARIABLES = CBS_5 Max_CBS_5_maanden .
FREQUENCIES VARIABLES = CBS_6 Max_CBS_6_maanden .
FREQUENCIES VARIABLES = CBS_7 Max_CBS_7_maanden .
FREQUENCIES VARIABLES = CBS_9 Max_CBS_9_maanden .

* Decide which offence category is responsible for the maximum sentence.
* The statements are ordered by decreasing severity .
* By checking whether the Offence_category has already been assigned we break ties .
COMPUTE Offence_category = 999 .
MISSING VALUES Offence_category (999) .
IF( MISSING( Offence_category ) AND Max_maanden = Max_CBS_3_maanden ) Offence_category = 2 .
IF( MISSING( Offence_category ) AND Max_maanden = Max_CBS_1_maanden ) Offence_category = 1 .
IF( MISSING( Offence_category ) AND Max_maanden = Max_CBS_2_maanden ) Offence_category = 3 .
IF( MISSING( Offence_category ) AND Max_maanden = Max_CBS_6_maanden ) Offence_category = 6 .
IF( MISSING( Offence_category ) AND Max_maanden = Max_CBS_7_maanden ) Offence_category = 7 .
IF( MISSING( Offence_category ) AND Max_maanden = Max_CBS_5_maanden ) Offence_category = 5 .
IF( MISSING( Offence_category ) AND Max_maanden = Max_CBS_9_maanden ) Offence_category = 9 .
IF( MISSING( Offence_category ) AND Max_maanden = Max_CBS_4_maanden ) Offence_category = 4 .
* There are hundreds of cases with a Wettelijke voorschriften but without a maximum .
IF( MISSING( Offence_category ) AND CBS = 1 ) Offence_category = 9 .
COMPUTE Offence_category_missing = Offence_category .
IF( MISSING( Offence_category ) )	 Offence_category_missing = 10 .
VARIABLE LABELS Offence_category "Offence category" .
VARIABLE LABELS Offence_category_missing "Offence category (Missing)" .

ADD VALUE LABELS Offence_category Offence_category_missing
	1 "Property offence"
	2 "Violent offence"
	3 "Public order offence"
	4 "Other criminal offence from the penal code"
	5 "Road traffic offence"
	6 "Drugs related offence"
	7 "Weapons related offence"
	9 "Other criminal offence"
	10 "(Missing)" .
FREQUENCIES VARIABLES = Offence_category Offence_category_missing .

* Dummy-code the Offence category .
COMPUTE Property_offence	= Offence_category = 1 .
COMPUTE Violent_offence		= Offence_category = 2 .
COMPUTE Public_order_offence	= Offence_category = 3 .
COMPUTE Other_penal_code_offence= Offence_category = 4 .
COMPUTE Road_traffic_offence	= Offence_category = 5 .
COMPUTE Drugs_offence		= Offence_category = 6 .
COMPUTE Weapons_offence		= Offence_category = 7 .
COMPUTE Other_criminal_offence	= Offence_category = 9 .
COMPUTE Total_criminal_offence	= Offence_category >= 1 AND Offence_category <= 9 .
FORMATS Property_offence TO Total_criminal_offence (F1.0) .
VARIABLE LABELS Property_offence		"Property offence" .
VARIABLE LABELS Violent_offence			"Violent offence" .
VARIABLE LABELS Public_order_offence		"Public order offence" .
VARIABLE LABELS Other_penal_code_offence	"Other criminal offence from the penal code" .
VARIABLE LABELS Road_traffic_offence		"Road traffic offence" .
VARIABLE LABELS Drugs_offence			"Drugs related offence" .
VARIABLE LABELS Weapons_offence			"Weapons related offence" .
VARIABLE LABELS Other_criminal_offence		"Other criminal offence" .
VARIABLE LABELS Total_criminal_offence		"Total criminal offences" .
FREQUENCIES VARIABLES = Property_offence TO Total_criminal_offence .

MISSING VALUES CBS_ids ("-") .
VARIABLE LABELS CBS_ids "CBS ids" .
VARIABLE LABELS CBS_ids_aantal "Number of CBS ids" .
FREQUENCIES VARIABLES=CBS_ids_aantal .

* Categorise the maximum prison sentence .
COMPUTE Max_maanden_category = 999 .
MISSING VALUES Max_maanden_category (999) .
IF(			Max_maanden < 72 )	Max_maanden_category = 0 .
IF( Max_maanden >=  72 AND Max_maanden <  96 )	Max_maanden_category = 1 .
IF( Max_maanden >=  96 AND Max_maanden < 108 )	Max_maanden_category = 2 .
IF( Max_maanden >= 108 AND Max_maanden < 120 )	Max_maanden_category = 3 .
IF( Max_maanden >= 120 AND Max_maanden < 144 )	Max_maanden_category = 4 .
IF( Max_maanden >= 144 AND Max_maanden < 180 )	Max_maanden_category = 5 .
IF( Max_maanden >= 180 AND Max_maanden < 216 )	Max_maanden_category = 6 .
IF( Max_maanden >= 216			)	Max_maanden_category = 7 .
ADD VALUE LABELS Max_maanden_category
	0 "Maximum prison months 71 and shorter"
	1 "Maximum prison months 72-95"
	2 "Maximum prison months 96-107"
	3 "Maximum prison months 108-119"
	4 "Maximum prison months 120-143"
	5 "Maximum prison months 144-179"
	6 "Maximum prison months 180-215"
	7 "Maximum prison months 216 and longer" .
FREQUENCIES VARIABLES=Max_maanden_category .

* Dummy-code the maximum prison sentence .
COMPUTE Max_maanden_dn_71	= Max_maanden_category = 0 .
COMPUTE Max_maanden_72_95	= Max_maanden_category = 1 .
COMPUTE Max_maanden_96_107	= Max_maanden_category = 2 .
COMPUTE Max_maanden_108_119	= Max_maanden_category = 3 .
COMPUTE Max_maanden_120_143	= Max_maanden_category = 4 .
COMPUTE Max_maanden_144_179	= Max_maanden_category = 5 .
COMPUTE Max_maanden_180_215	= Max_maanden_category = 6 .
COMPUTE Max_maanden_216_up	= Max_maanden_category = 7 .
FORMATS Max_maanden_dn_71 TO Max_maanden_216_up (F1.0) .
VARIABLE LABELS Max_maanden_dn_71	"Maximum prison months 71 and shorter" .
VARIABLE LABELS Max_maanden_72_95	"Maximum prison months 72-95" .
VARIABLE LABELS Max_maanden_96_107	"Maximum prison months 96-107" .
VARIABLE LABELS Max_maanden_108_119	"Maximum prison months 108-119" .
VARIABLE LABELS Max_maanden_120_143	"Maximum prison months 120-143" .
VARIABLE LABELS Max_maanden_144_179	"Maximum prison months 144-179" .
VARIABLE LABELS Max_maanden_180_215	"Maximum prison months 180-215" .
VARIABLE LABELS Max_maanden_216_up	"Maximum prison months 216 and longer" .
FREQUENCIES VARIABLES=Max_maanden_dn_71 TO Max_maanden_216_up .

VARIABLE LABELS Max_maanden "Maximum prison months" .
FREQUENCIES VARIABLES=Max_maanden /FORMAT=DFREQ .

FREQUENCIES VARIABLES=Tools .

COMPUTE Bank_involved = ( Bank ~= "-" ) .
VARIABLE LABELS Bank_involved "Are Banks involved" .
FORMATS Bank_involved (F1.0) .
ADD VALUE LABELS Bank_involved 0 "Banks are not involved" 1 "Banks are involved" .
FREQUENCIES VARIABLES=Bank Bank_involved .

COMPUTE Guidelines = ( Richtlijnen ~= "-" ) .
VARIABLE LABELS Guidelines "Have guidelines been mentioned" .
FORMATS Guidelines (F1.0) .
ADD VALUE LABELS Guidelines 0 "Guidelines have not been mentioned" 1 "Guidelines have been mentioned" .
FREQUENCIES VARIABLES=Richtlijnen Guidelines .

VARIABLE LABELS Expertise_verdachte "Expertise offender" .
FREQUENCIES VARIABLES=Expertise_verdachte /FORMAT=DFREQ .

COMPUTE Has_offender_basic_expertise = ( Internet ~= "-" ) AND ( NOT ( Expertise_verdachte ~= "-" OR Vertrouwelijkheid ~= "-" ) ) .
VARIABLE LABELS Has_offender_basic_expertise "Has offender basic expertise" .
FORMATS Has_offender_basic_expertise (F1.0) .
ADD VALUE LABELS Has_offender_basic_expertise 0 "Offender without basic expertise" 1 "Offender with basic expertise" .
FREQUENCIES VARIABLES=Has_offender_basic_expertise .

COMPUTE Has_offender_special_expertise = ( Expertise_verdachte ~= "-" OR Vertrouwelijkheid ~= "-" ) .
VARIABLE LABELS Has_offender_special_expertise "Has offender special expertise" .
FORMATS Has_offender_special_expertise (F1.0) .
ADD VALUE LABELS Has_offender_special_expertise 0 "Offender without special expertise" 1 "Offender with special expertise" .
FREQUENCIES VARIABLES=Has_offender_special_expertise .

COMPUTE Expertise_category = 0 .
IF( Vertrouwelijkheid ~= "-"  ) Expertise_category = 1 .
IF( Expertise_verdachte ~= "-") Expertise_category = 2 .
IF( Expertise_verdachte ~= "-" AND Vertrouwelijkheid ~= "-"  ) Expertise_category = 3 .
ADD VALUE LABELS Expertise_category
	0 "No special technnology"
	1 "Anonymity technnology"
	2 "Confidentiality technology"
	3 "Anonymity and confidentiality technnology" .
FREQUENCIES VARIABLES=Expertise_category .

VARIABLE LABELS Expertise_rechtbank "Expertise district court" .
FREQUENCIES VARIABLES=Expertise_rechtbank /FORMAT=DFREQ .

COMPUTE Has_prosecution_special_expertise = ( Expertise_rechtbank ~= "-" OR Opsporing ~= "-" ) .
VARIABLE LABELS Has_prosecution_special_expertise "Has prosecution special expertise" .
FORMATS Has_prosecution_special_expertise (F1.0) .
ADD VALUE LABELS Has_prosecution_special_expertise 0 "Prosecution without special expertise" 1 "Prosecution with special expertise" .
FREQUENCIES VARIABLES=Has_prosecution_special_expertise .

******************************************************************************************** .
* Check for time dependencies
******************************************************************************************** .
ONEWAY Age_at_sentencing BY Year_sentence
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

CROSSTABS
	/TABLES=Is_born_abroad BY Year_sentence
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Is_female_offender BY Year_sentence
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Is_repeat_offender BY Year_sentence
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_cooffenders BY Year_sentence
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_multiple_victims BY Year_sentence
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_offender_basic_expertise BY Year_sentence
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_offender_special_expertise BY Year_sentence
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_prosecution_special_expertise BY Year_sentence
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

ONEWAY Max_maanden BY Year_sentence
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

ONEWAY Straf_Maanden BY Year_sentence
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* Check for age dependencies
******************************************************************************************** .
ONEWAY Age_at_sentencing BY Age_category
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

CROSSTABS
	/TABLES=Is_born_abroad BY Age_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Is_female_offender BY Age_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Is_repeat_offender BY Age_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_cooffenders BY Age_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_multiple_victims BY Age_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_offender_basic_expertise BY Age_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_offender_special_expertise BY Age_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_prosecution_special_expertise BY Age_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

ONEWAY Max_maanden BY Age_category
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

ONEWAY Straf_Maanden BY Age_category
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* Check for maximum sentence dependencies
******************************************************************************************** .
ONEWAY Age_at_sentencing BY Max_maanden_category
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

CROSSTABS
	/TABLES=Is_born_abroad BY Max_maanden_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Is_female_offender BY Max_maanden_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Is_repeat_offender BY Max_maanden_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_cooffenders BY Max_maanden_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_multiple_victims BY Max_maanden_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_offender_basic_expertise BY Max_maanden_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_offender_special_expertise BY Max_maanden_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_prosecution_special_expertise BY Max_maanden_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

ONEWAY Max_maanden BY Max_maanden_category
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

ONEWAY Straf_Maanden BY Max_maanden_category
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* Check for Intensity dependencies .
******************************************************************************************** .
COMPUTE Is_large_scale = CHAR.INDEX( Intensiteit, "Grootschalig" ) > 0 .
VARIABLE LABELS Is_large_scale "Is large scale offence or investigation" .
ADD VALUE LABELS Is_large_scale 0 "Small scale" 1 "Large scale" .

CROSSTABS
	/TABLES=Decision BY Is_large_scale
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

CROSSTABS
	/TABLES=Has_offender_special_expertise BY Is_large_scale
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

******************************************************************************************** .
* Check for Danger dependencies .
******************************************************************************************** .
COMPUTE Danger_category = 0 .
IF( CHAR.INDEX( Gevaar, "Gevaar" ) > 0 ) 	Danger_category = Danger_category + 1 .
IF( CHAR.INDEX( Gevaar, "Vuurwapen" ) > 0 ) 	Danger_category = Danger_category + 2 .
IF( CHAR.INDEX( Gevaar, "Witwassen" ) > 0 ) 	Danger_category = Danger_category + 4 .
ADD VALUE LABELS Danger_category
	0 "Not known to be dangerous"
	1 "General"
	2 "Fire arms"
	3 "General & fire arms"
	4 "Money laundering"
	5 "General & money laundering"
	6 "Fire arms & money laundering"
	7 "General & fire arms & money laundering" .

CROSSTABS
	/TABLES=Decision BY Danger_category
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

COMPUTE Is_Dangerous = CHAR.INDEX( Gevaar, "Gevaar" ) > 0 .
VARIABLE LABELS Is_dangerous "Is dangerous offender" .
ADD VALUE LABELS Is_dangerous 0 "Offender is not known to be dangerous" 1 "Offender is dangerous" .

CROSSTABS
	/TABLES=Has_offender_special_expertise BY Is_Dangerous
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

******************************************************************************************** .
* We expect that women more often do community service .
******************************************************************************************** .
CROSSTABS
	/TABLES=Is_female_offender BY Has_prison_sentence
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW
	/COUNT ROUND CELL .

******************************************************************************************** .
* We expect courts to have different expertise .
******************************************************************************************** .
CROSSTABS
	/TABLES= Is_specialised_court BY Has_prosecution_special_expertise
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW
	/COUNT ROUND CELL .

******************************************************************************************** .
* We expect women to have longer sentences because women more often accept an out of court settlement to care for their children .
******************************************************************************************** .
ONEWAY Ln_Straf_maanden BY Is_female_offender
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* We expect foreigners to have similar sentences as locals .
******************************************************************************************** .
ONEWAY Ln_Straf_maanden BY Is_born_abroad
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* We expect repeat offenders to have longer sentences .
******************************************************************************************** .
ONEWAY Ln_Straf_maanden BY Is_repeat_offender
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* We expect offenders with basic expertise to receive shorted sentences because they are less of a danger .
******************************************************************************************** .
ONEWAY Ln_Straf_maanden BY Has_offender_basic_expertise
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* We expect the expertise of the offenders to make no difference to the sentence .
******************************************************************************************** .
ONEWAY Ln_Straf_maanden BY Has_offender_special_expertise
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* We expect money laundering to increase the sentences .
******************************************************************************************** .
ONEWAY Ln_Straf_maanden BY CBS_1_7
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* We expect illegal weapons to increase the sentences .
******************************************************************************************** .
ONEWAY Ln_Straf_maanden BY CBS_7
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* We expect specialised courts to process different cases .
******************************************************************************************** .
ONEWAY Ln_Straf_maanden BY Is_specialised_court
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* We expect special expertise to be matched .
******************************************************************************************** .
CROSSTABS
	/TABLES= Has_offender_special_expertise BY Has_prosecution_special_expertise
	/STATISTICS=CHISQ
	/FORMAT=AVALUE TABLES
	/CELL=COUNT ROW COL
	/COUNT ROUND CELL .

******************************************************************************************** .
* Provide some descriptive statistics .
******************************************************************************************** .
FREQUENCIES
	/VARIABLES=
		Taakstraf
		Max_maanden_dn_71 TO Max_maanden_216_up
		Property_offence TO Other_criminal_offence
		Guidelines
		Has_prosecution_special_expertise
		Age_dn_17 TO Age_51_up
		Is_born_abroad
		Is_female_offender
		Is_repeat_offender
		Has_multiple_victims
		Has_offender_basic_expertise
		Has_offender_special_expertise .

DESCRIPTIVES
	/VARIABLES=
		Max_maanden
		Offence_count
		Age_at_sentencing
		Straf_maanden
	/STATISTICS=
		MEAN
		STDDEV
		MIN
		MAX
		SUM .

ONEWAY Age_at_sentencing BY Age_category
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

ONEWAY Max_maanden BY Max_maanden_category
	/STATISTICS DESCRIPTIVES
	/MISSING ANALYSIS .

******************************************************************************************** .
* We expect the offence to explain most of the variance in the sentence length .
******************************************************************************************** .
REGRESSION
	/DESCRIPTIVES MEAN STDDEV CORR SIG N
	/MISSING LISTWISE
	/STATISTICS COEFF OUTS CI(95) R ANOVA COLLIN TOL CHANGE ZPP
	/CRITERIA=PIN(.05) POUT(.10)
	/NOORIGIN
	/DEPENDENT Ln_Straf_maanden
	/METHOD=ENTER
		Max_maanden_dn_71 Max_maanden_72_95 Max_maanden_96_107 Max_maanden_120_143 Max_maanden_144_179 Max_maanden_180_215 Max_maanden_216_up
		Property_offence Public_order_offence Other_penal_code_offence Road_traffic_offence Drugs_offence Weapons_offence Other_criminal_offence
		Offence_count
	/METHOD=ENTER
		Guidelines
		Has_prosecution_special_expertise
	/METHOD=ENTER
		Age_dn_17 Age_18_20 Age_31_40 Age_41_50 Age_51_up
		Is_born_abroad
		Is_female_offender
		Is_repeat_offender
		Has_multiple_victims
		Has_offender_basic_expertise
		Has_offender_special_expertise
	/RESIDUALS DURBIN HISTOGRAM(ZRESID) NORMPROB(ZRESID) ID(ECLI)
	/CASEWISE OUTLIERS(3)
	/SAVE PRED COOK LEVER SRESID SDRESID .

* Chart Builder .
GGRAPH
	/GRAPHDATASET NAME="graphdataset" VARIABLES=PRE_1 SRE_1 MISSING=LISTWISE REPORTMISSING=NO
	/GRAPHSPEC SOURCE=INLINE
	/FITLINE TOTAL=NO .
BEGIN GPL
	SOURCE: s=userSource(id("graphdataset"))
	DATA: PRE_1=col(source(s), name("PRE_1"))
	DATA: SRE_1=col(source(s), name("SRE_1"))
	GUIDE: axis(dim(1), label("Unstandardized Predicted Value"))
	GUIDE: axis(dim(2), label("Studentized Residual"))
	GUIDE: text.title(label("Simple Scatter of Studentized Residual by Unstandardized Predicted ", "Value"))
	ELEMENT: point(position(PRE_1*SRE_1))
END GPL .

SORT CASES BY Taakstraf .
SPLIT FILE BY Taakstraf .
******************************************************************************************** .
* We expect interaction effects .
******************************************************************************************** .
REGRESSION
	/DESCRIPTIVES MEAN STDDEV CORR SIG N
	/MISSING LISTWISE
	/STATISTICS COEFF OUTS CI(95) R ANOVA COLLIN TOL CHANGE ZPP
	/CRITERIA=PIN(.05) POUT(.10)
	/NOORIGIN
	/DEPENDENT Ln_Straf_maanden
	/METHOD=ENTER
		Max_maanden_dn_71 Max_maanden_72_95 Max_maanden_96_107 Max_maanden_120_143 Max_maanden_144_179 Max_maanden_180_215 Max_maanden_216_up
		Property_offence Public_order_offence Other_penal_code_offence Road_traffic_offence Drugs_offence Weapons_offence Other_criminal_offence
		Offence_count
	/METHOD=ENTER
		Guidelines
		Has_prosecution_special_expertise
	/METHOD=ENTER
		Age_dn_17 Age_18_20 Age_31_40 Age_41_50 Age_51_up
		Is_born_abroad
		Is_female_offender
		Is_repeat_offender
		Has_multiple_victims
		Has_offender_basic_expertise
		Has_offender_special_expertise .

SPLIT FILE OFF.

******************************************************************************************** .
* We expect interaction effects .
******************************************************************************************** .

COMPUTE Negate_Has_prosecution_special_expertise = 1 - Has_prosecution_special_expertise .
COMPUTE Max_maanden_dn_71_x_Negate_Has_prosecution_special_expertise = Max_maanden_dn_71 * Negate_Has_prosecution_special_expertise .
COMPUTE Max_maanden_72_95_x_Negate_Has_prosecution_special_expertise = Max_maanden_72_95 * Negate_Has_prosecution_special_expertise .
COMPUTE Max_maanden_96_107_x_Negate_Has_prosecution_special_expertise = Max_maanden_96_107 * Negate_Has_prosecution_special_expertise .
COMPUTE Max_maanden_120_143_x_Negate_Has_prosecution_special_expertise = Max_maanden_120_143 * Negate_Has_prosecution_special_expertise .
COMPUTE Max_maanden_144_179_x_Negate_Has_prosecution_special_expertise = Max_maanden_144_179 * Negate_Has_prosecution_special_expertise .
COMPUTE Max_maanden_180_215_x_Negate_Has_prosecution_special_expertise = Max_maanden_180_215 * Negate_Has_prosecution_special_expertise .
COMPUTE Max_maanden_216_up_x_Negate_Has_prosecution_special_expertise = Max_maanden_216_up * Negate_Has_prosecution_special_expertise .
REGRESSION
	/DESCRIPTIVES MEAN STDDEV CORR SIG N
	/MISSING LISTWISE
	/STATISTICS COEFF OUTS CI(95) R ANOVA COLLIN TOL CHANGE ZPP
	/CRITERIA=PIN(.05) POUT(.10)
	/NOORIGIN
	/DEPENDENT Ln_Straf_maanden
	/METHOD=ENTER
		Max_maanden_dn_71 Max_maanden_72_95 Max_maanden_96_107 Max_maanden_120_143 Max_maanden_144_179 Max_maanden_180_215 Max_maanden_216_up
		Property_offence Public_order_offence Other_penal_code_offence Road_traffic_offence Drugs_offence Weapons_offence Other_criminal_offence
		Offence_count
	/METHOD=ENTER
		Guidelines
		Has_prosecution_special_expertise
	/METHOD=ENTER
		Age_dn_17 Age_18_20 Age_31_40 Age_41_50 Age_51_up
		Is_born_abroad
		Is_female_offender
		Is_repeat_offender
		Has_multiple_victims
		Has_offender_basic_expertise
		Has_offender_special_expertise
	/METHOD=ENTER
		Max_maanden_dn_71_x_Negate_Has_prosecution_special_expertise
		Max_maanden_72_95_x_Negate_Has_prosecution_special_expertise
		Max_maanden_96_107_x_Negate_Has_prosecution_special_expertise
		Max_maanden_120_143_x_Negate_Has_prosecution_special_expertise
		Max_maanden_144_179_x_Negate_Has_prosecution_special_expertise
		Max_maanden_180_215_x_Negate_Has_prosecution_special_expertise
		Max_maanden_216_up_x_Negate_Has_prosecution_special_expertise .

COMPUTE Max_maanden_dn_71_x_Has_prosecution_special_expertise = Max_maanden_dn_71 * Has_prosecution_special_expertise .
COMPUTE Max_maanden_72_95_x_Has_prosecution_special_expertise = Max_maanden_72_95 * Has_prosecution_special_expertise .
COMPUTE Max_maanden_96_107_x_Has_prosecution_special_expertise = Max_maanden_96_107 * Has_prosecution_special_expertise .
COMPUTE Max_maanden_120_143_x_Has_prosecution_special_expertise = Max_maanden_120_143 * Has_prosecution_special_expertise .
COMPUTE Max_maanden_144_179_x_Has_prosecution_special_expertise = Max_maanden_144_179 * Has_prosecution_special_expertise .
COMPUTE Max_maanden_180_215_x_Has_prosecution_special_expertise = Max_maanden_180_215 * Has_prosecution_special_expertise .
COMPUTE Max_maanden_216_up_x_Has_prosecution_special_expertise = Max_maanden_216_up * Has_prosecution_special_expertise .
REGRESSION
	/DESCRIPTIVES MEAN STDDEV CORR SIG N
	/MISSING LISTWISE
	/STATISTICS COEFF OUTS CI(95) R ANOVA COLLIN TOL CHANGE ZPP
	/CRITERIA=PIN(.05) POUT(.10)
	/NOORIGIN
	/DEPENDENT Ln_Straf_maanden
	/METHOD=ENTER
		Max_maanden_dn_71 Max_maanden_72_95 Max_maanden_96_107 Max_maanden_120_143 Max_maanden_144_179 Max_maanden_180_215 Max_maanden_216_up
		Property_offence Public_order_offence Other_penal_code_offence Road_traffic_offence Drugs_offence Weapons_offence Other_criminal_offence
		Offence_count
	/METHOD=ENTER
		Guidelines
		Has_prosecution_special_expertise
	/METHOD=ENTER
		Age_dn_17 Age_18_20 Age_31_40 Age_41_50 Age_51_up
		Is_born_abroad
		Is_female_offender
		Is_repeat_offender
		Has_multiple_victims
		Has_offender_basic_expertise
		Has_offender_special_expertise
	/METHOD=ENTER
		Max_maanden_dn_71_x_Has_prosecution_special_expertise
		Max_maanden_72_95_x_Has_prosecution_special_expertise
		Max_maanden_96_107_x_Has_prosecution_special_expertise
		Max_maanden_120_143_x_Has_prosecution_special_expertise
		Max_maanden_144_179_x_Has_prosecution_special_expertise
		Max_maanden_180_215_x_Has_prosecution_special_expertise
		Max_maanden_216_up_x_Has_prosecution_special_expertise .

COMPUTE Negate_Is_repeat_offender = 1 - Is_repeat_offender .
COMPUTE Age_dn_17_x_Negate_Is_repeat_offender = Age_dn_17 * Negate_Is_repeat_offender .
COMPUTE Age_18_20_x_Negate_Is_repeat_offender = Age_18_20 * Negate_Is_repeat_offender .
COMPUTE Age_31_40_x_Negate_Is_repeat_offender = Age_31_40 * Negate_Is_repeat_offender .
COMPUTE Age_41_50_x_Negate_Is_repeat_offender = Age_41_50 * Negate_Is_repeat_offender .
COMPUTE Age_51_up_x_Negate_Is_repeat_offender = Age_51_up * Negate_Is_repeat_offender .
REGRESSION
	/DESCRIPTIVES MEAN STDDEV CORR SIG N
	/MISSING LISTWISE
	/STATISTICS COEFF OUTS CI(95) R ANOVA COLLIN TOL CHANGE ZPP
	/CRITERIA=PIN(.05) POUT(.10)
	/NOORIGIN
	/DEPENDENT Ln_Straf_maanden
	/METHOD=ENTER
		Max_maanden_dn_71 Max_maanden_72_95 Max_maanden_96_107 Max_maanden_120_143 Max_maanden_144_179 Max_maanden_180_215 Max_maanden_216_up
		Property_offence Public_order_offence Other_penal_code_offence Road_traffic_offence Drugs_offence Weapons_offence Other_criminal_offence
		Offence_count
	/METHOD=ENTER
		Guidelines
		Has_prosecution_special_expertise
	/METHOD=ENTER
		Age_dn_17 Age_18_20 Age_31_40 Age_41_50 Age_51_up
		Is_born_abroad
		Is_female_offender
		Negate_Is_repeat_offender
		Has_multiple_victims
		Has_offender_basic_expertise
		Has_offender_special_expertise
	/METHOD=ENTER
		Age_dn_17_x_Negate_Is_repeat_offender
		Age_18_20_x_Negate_Is_repeat_offender
		Age_31_40_x_Negate_Is_repeat_offender
		Age_41_50_x_Negate_Is_repeat_offender
		Age_51_up_x_Negate_Is_repeat_offender .

COMPUTE Age_dn_17_x_Is_repeat_offender = Age_dn_17 * Is_repeat_offender .
COMPUTE Age_18_20_x_Is_repeat_offender = Age_18_20 * Is_repeat_offender .
COMPUTE Age_31_40_x_Is_repeat_offender = Age_31_40 * Is_repeat_offender .
COMPUTE Age_41_50_x_Is_repeat_offender = Age_41_50 * Is_repeat_offender .
COMPUTE Age_51_up_x_Is_repeat_offender = Age_51_up * Is_repeat_offender .
REGRESSION
	/DESCRIPTIVES MEAN STDDEV CORR SIG N
	/MISSING LISTWISE
	/STATISTICS COEFF OUTS CI(95) R ANOVA COLLIN TOL CHANGE ZPP
	/CRITERIA=PIN(.05) POUT(.10)
	/NOORIGIN
	/DEPENDENT Ln_Straf_maanden
	/METHOD=ENTER
		Max_maanden_dn_71 Max_maanden_72_95 Max_maanden_96_107 Max_maanden_120_143 Max_maanden_144_179 Max_maanden_180_215 Max_maanden_216_up
		Property_offence Public_order_offence Other_penal_code_offence Road_traffic_offence Drugs_offence Weapons_offence Other_criminal_offence
		Offence_count
	/METHOD=ENTER
		Guidelines
		Has_prosecution_special_expertise
	/METHOD=ENTER
		Age_dn_17 Age_18_20 Age_31_40 Age_41_50 Age_51_up
		Is_born_abroad
		Is_female_offender
		Is_repeat_offender
		Has_multiple_victims
		Has_offender_basic_expertise
		Has_offender_special_expertise
	/METHOD=ENTER
		Age_dn_17_x_Is_repeat_offender
		Age_18_20_x_Is_repeat_offender
		Age_31_40_x_Is_repeat_offender
		Age_41_50_x_Is_repeat_offender
		Age_51_up_x_Is_repeat_offender .

COMPUTE Negate_Has_offender_special_expertise = 1 - Has_offender_special_expertise .
COMPUTE Property_offence_x_Negate_Has_offender_special_expertise = Property_offence * Negate_Has_offender_special_expertise .
COMPUTE Public_order_offence_x_Negate_Has_offender_special_expertise = Public_order_offence * Negate_Has_offender_special_expertise .
COMPUTE Other_penal_code_offence_x_Negate_Has_offender_special_expertise = Other_penal_code_offence * Negate_Has_offender_special_expertise .
COMPUTE Road_traffic_offence_x_Negate_Has_offender_special_expertise = Road_traffic_offence * Negate_Has_offender_special_expertise .
COMPUTE Drugs_offence_x_Negate_Has_offender_special_expertise = Drugs_offence * Negate_Has_offender_special_expertise .
COMPUTE Weapons_offence_x_Negate_Has_offender_special_expertise = Weapons_offence * Negate_Has_offender_special_expertise .
COMPUTE Drugs_offence_x_Negate_Has_offender_special_expertise = Drugs_offence * Negate_Has_offender_special_expertise .
COMPUTE Other_criminal_offence_x_Negate_Has_offender_special_expertise = Other_criminal_offence * Negate_Has_offender_special_expertise .
REGRESSION
	/DESCRIPTIVES MEAN STDDEV CORR SIG N
	/MISSING LISTWISE
	/STATISTICS COEFF OUTS CI(95) R ANOVA COLLIN TOL CHANGE ZPP
	/CRITERIA=PIN(.05) POUT(.10)
	/NOORIGIN
	/DEPENDENT Ln_Straf_maanden
	/METHOD=ENTER
		Max_maanden_dn_71 Max_maanden_72_95 Max_maanden_96_107 Max_maanden_120_143 Max_maanden_144_179 Max_maanden_180_215 Max_maanden_216_up
		Property_offence Public_order_offence Other_penal_code_offence Road_traffic_offence Drugs_offence Weapons_offence Other_criminal_offence
		Offence_count
	/METHOD=ENTER
		Guidelines
		Has_prosecution_special_expertise
	/METHOD=ENTER
		Age_dn_17 Age_18_20 Age_31_40 Age_41_50 Age_51_up
		Is_born_abroad
		Is_female_offender
		Is_repeat_offender
		Has_multiple_victims
		Has_offender_basic_expertise
		Has_offender_special_expertise
	/METHOD=ENTER
		Property_offence_x_Negate_Has_offender_special_expertise
		Public_order_offence_x_Negate_Has_offender_special_expertise
		Other_penal_code_offence_x_Negate_Has_offender_special_expertise
		Road_traffic_offence_x_Negate_Has_offender_special_expertise
		Drugs_offence_x_Negate_Has_offender_special_expertise
		Weapons_offence_x_Negate_Has_offender_special_expertise
		Other_criminal_offence_x_Negate_Has_offender_special_expertise .

COMPUTE Property_offence_x_Has_offender_special_expertise = Property_offence * Has_offender_special_expertise .
COMPUTE Public_order_offence_x_Has_offender_special_expertise = Public_order_offence * Has_offender_special_expertise .
COMPUTE Other_penal_code_offence_x_Has_offender_special_expertise = Other_penal_code_offence * Has_offender_special_expertise .
COMPUTE Road_traffic_offence_x_Has_offender_special_expertise = Road_traffic_offence * Has_offender_special_expertise .
COMPUTE Drugs_offence_x_Has_offender_special_expertise = Drugs_offence * Has_offender_special_expertise .
COMPUTE Weapons_offence_x_Has_offender_special_expertise = Weapons_offence * Has_offender_special_expertise .
COMPUTE Drugs_offence_x_Has_offender_special_expertise = Drugs_offence * Has_offender_special_expertise .
COMPUTE Other_criminal_offence_x_Has_offender_special_expertise = Other_criminal_offence * Has_offender_special_expertise .
REGRESSION
	/DESCRIPTIVES MEAN STDDEV CORR SIG N
	/MISSING LISTWISE
	/STATISTICS COEFF OUTS CI(95) R ANOVA COLLIN TOL CHANGE ZPP
	/CRITERIA=PIN(.05) POUT(.10)
	/NOORIGIN
	/DEPENDENT Ln_Straf_maanden
	/METHOD=ENTER
		Max_maanden_dn_71 Max_maanden_72_95 Max_maanden_96_107 Max_maanden_120_143 Max_maanden_144_179 Max_maanden_180_215 Max_maanden_216_up
		CBS_1 CBS_3 CBS_2 CBS_6 CBS_7
	/METHOD=ENTER
		Guidelines
		Has_prosecution_special_expertise
	/METHOD=ENTER
		Age_dn_17 Age_18_20 Age_31_40 Age_41_50 Age_51_up
		Is_born_abroad
		Is_female_offender
		Is_repeat_offender
		Has_multiple_victims
		Has_offender_basic_expertise
		Has_offender_special_expertise
	/METHOD=ENTER
		Property_offence_x_Has_offender_special_expertise
		Public_order_offence_x_Has_offender_special_expertise
		Other_penal_code_offence_x_Has_offender_special_expertise
		Road_traffic_offence_x_Has_offender_special_expertise
		Drugs_offence_x_Has_offender_special_expertise
		Weapons_offence_x_Has_offender_special_expertise
		Other_criminal_offence_x_Has_offender_special_expertise .

******************************************************************************************** .
* Multiple correspondence analysis.
******************************************************************************************** .
COMPUTE Max_maanden_dn_71_plus_1 = Max_maanden_dn_71 + 1 .
COMPUTE Max_maanden_72_95_plus_1 = Max_maanden_72_95 + 1 .
COMPUTE Max_maanden_96_107_plus_1 = Max_maanden_96_107 + 1 .
COMPUTE Max_maanden_108_119_plus_1 = Max_maanden_108_119 + 1 .
COMPUTE Max_maanden_120_143_plus_1 = Max_maanden_120_143 + 1 .
COMPUTE Max_maanden_144_179_plus_1 = Max_maanden_144_179 + 1 .
COMPUTE Max_maanden_180_215_plus_1 = Max_maanden_180_215 + 1 .
COMPUTE Max_maanden_216_up_plus_1 = Max_maanden_216_up + 1 .
COMPUTE Property_offence_plus_1 = Property_offence + 1 .
COMPUTE Public_order_offence_plus_1 = Public_order_offence + 1 .
COMPUTE Other_penal_code_offence_plus_1 = Other_penal_code_offence + 1 .
COMPUTE Road_traffic_offence_plus_1 = Road_traffic_offence + 1 .
COMPUTE Drugs_offence_plus_1 = Drugs_offence + 1 .
COMPUTE Weapons_offence_plus_1 = Weapons_offence + 1 .
COMPUTE Other_criminal_offence_plus_1 = Other_criminal_offence + 1 .
COMPUTE Guidelines_plus_1 = Guidelines + 1 .
COMPUTE Has_prosecution_special_expertise_plus_1 = Has_prosecution_special_expertise + 1 .
COMPUTE Age_dn_17_plus_1 = Age_dn_17 + 1 .
COMPUTE Age_18_20_plus_1 = Age_18_20 + 1 .
COMPUTE Age_21_30_plus_1 = Age_21_30 + 1 .
COMPUTE Age_31_40_plus_1 = Age_31_40 + 1 .
COMPUTE Age_41_50_plus_1 = Age_41_50 + 1 .
COMPUTE Age_51_up_plus_1 = Age_51_up + 1 .
COMPUTE Is_born_abroad_plus_1 = Is_born_abroad + 1 .
COMPUTE Is_female_offender_plus_1 = Is_female_offender + 1 .
COMPUTE Is_repeat_offender_plus_1 = Is_repeat_offender + 1 .
COMPUTE Has_multiple_victims_plus_1 = Has_multiple_victims + 1 .
COMPUTE Has_offender_basic_expertise_plus_1 = Has_offender_basic_expertise + 1 .
COMPUTE Has_offender_special_expertise_plus_1 = Has_offender_special_expertise + 1 .

DEFINE !CategoricalPCA( ndimensions=!TOKENS(1) ) .
!DO !dim = 2 !TO 7
CATPCA VARIABLES=
		Max_maanden_dn_71_plus_1
		Max_maanden_72_95_plus_1
		Max_maanden_96_107_plus_1
		Max_maanden_120_143_plus_1
		Max_maanden_144_179_plus_1
		Max_maanden_180_215_plus_1
		Max_maanden_216_up_plus_1
		Property_offence_plus_1
		Public_order_offence_plus_1
		Other_penal_code_offence_plus_1
		Road_traffic_offence_plus_1
		Drugs_offence_plus_1
		Weapons_offence_plus_1
		Other_criminal_offence_plus_1
		Guidelines_plus_1
		Has_prosecution_special_expertise_plus_1
		Age_dn_17_plus_1
		Age_18_20_plus_1
		Age_31_40_plus_1
		Age_41_50_plus_1
		Age_51_up_plus_1
		Is_born_abroad_plus_1
		Is_female_offender_plus_1
		Is_repeat_offender_plus_1
		Has_multiple_victims_plus_1
		Has_offender_basic_expertise_plus_1
		Has_offender_special_expertise_plus_1
	/ANALYSIS=Max_maanden_dn_71_plus_1 TO Has_offender_special_expertise_plus_1
	/MISSING=Max_maanden_dn_71_plus_1 TO Has_offender_special_expertise_plus_1
	/DIMENSION=!dim .
!DOEND .
!ENDDEFINE .

!CategoricalPCA .

COMPUTE Ln_Straf_maanden_category = 999 .
MISSING VALUES Ln_Straf_maanden_category (999) .
VARIABLE LABELS Ln_Straf_maanden_category "Ln( Prison months ) -- rounded to nearest 0.25 --" .
IF( ~MISSING( Ln_Straf_maanden ) ) Ln_Straf_maanden_category = RND( Ln_Straf_maanden, 0.25 ) .
FORMATS Ln_Straf_maanden_category (F3.2) .
GRAPH
	/HISTOGRAM(NORMAL)=Ln_Straf_maanden_category .

COMPUTE Age_at_sentencing_category = 999 .
MISSING VALUES Age_at_sentencing_category (999) .
VARIABLE LABELS Age_at_sentencing_category "Age at sentencing -- rounded to nearest 5 fold --" .
IF( ~MISSING( Age_at_sentencing ) ) Age_at_sentencing_category = RND( MIN( Age_at_sentencing, 65 ), 5 ) .
FORMATS Age_at_sentencing_category (F2.0) .
GRAPH
	/ERRORBAR(CI 95)=Straf_maanden BY Age_at_sentencing_category BY Is_female_offender .

GRAPH
	/ERRORBAR(CI 95)=Straf_maanden BY Age_at_sentencing_category BY Guidelines .

GRAPH
	/ERRORBAR(CI 95)=Straf_maanden BY Age_at_sentencing_category BY Has_prosecution_special_expertise .

GRAPH
	/ERRORBAR(CI 95)=Straf_maanden BY Age_at_sentencing_category BY Has_offender_basic_expertise .

GRAPH
	/ERRORBAR(CI 95)=Straf_maanden BY Age_at_sentencing_category BY Has_offender_special_expertise .

GRAPH
	/ERRORBAR(CI 95)=Straf_maanden BY Year_sentence BY Has_offender_basic_expertise .

GRAPH
	/ERRORBAR(CI 95)=Straf_maanden BY Year_sentence BY Has_offender_special_expertise .

GRAPH
	/ERRORBAR(CI 95)=Straf_maanden BY Year_sentence BY Guidelines .

GRAPH
	/ERRORBAR(CI 95)=Straf_maanden BY Year_sentence BY Has_prosecution_special_expertise .

SPLIT FILE OFF .

******************************************************************************************** .
* Create tables .
******************************************************************************************** .
* Uncomment the next three statements to get clean tables [EDIT].

MISSING VALUES Property_offence TO Total_criminal_offence (0) .
MISSING VALUES Year_sentence (999) .
MISSING VALUES CBS TO CBS_9 (0) .

CTABLES
	/VLABELS VARIABLES = Property_offence TO Total_criminal_offence
		DISPLAY=LABEL
	/TABLE (Property_offence +
		Violent_offence +
		Public_order_offence +
		Other_penal_code_offence +
		Road_traffic_offence +
		Drugs_offence +
		Weapons_offence +
		Other_criminal_offence +
		Total_criminal_offence) > Mode [COUNT TOTALS [COUNT]] BY Year_sentence
	/CATEGORIES VARIABLES = Year_sentence TOTAL=YES .

CTABLES
	/VLABELS VARIABLES = CBS CBS_1 CBS_3 CBS_2 CBS_4 CBS_5 CBS_6 CBS_7 CBS_9
		DISPLAY=LABEL
	/TABLE (CBS + CBS_1 + CBS_3 + CBS_2 + CBS_4 + CBS_5 + CBS_6 + CBS_7 + CBS_9) > Mode [COUNT TOTALS [COUNT]] BY Year_sentence
	/CATEGORIES VARIABLES = Year_sentence TOTAL=YES .

CTABLES
	/VLABELS VARIABLES = CBS TO CBS_9
		DISPLAY=LABEL
	/TABLE (CBS +
		CBS_1 + CBS_1_1 + CBS_1_2 + CBS_1_3 + CBS_1_4 + CBS_1_5 + CBS_1_6 + CBS_1_7 + CBS_1_8 +
		CBS_3 + CBS_3_1 + CBS_3_2 + CBS_3_3 + CBS_3_4 + CBS_3_5 + CBS_3_6 + CBS_3_7 +
		CBS_2 + CBS_2_1 + CBS_2_2 + CBS_2_3 + CBS_2_4 +
		CBS_4 +
		CBS_5 +
		CBS_6 + CBS_6_1 + CBS_6_2 + CBS_6_3 +
		CBS_7 +
		CBS_9 ) > Mode [COUNT TOTALS [COUNT]] BY Year_sentence
	/CATEGORIES VARIABLES = Year_sentence TOTAL=YES .

