// Dependencies
const fs = require( 'fs' ) ;

// Truncate a long txt
function _truncate( txt, max ) {
	if( typeof txt === 'string' && max >= 0 && txt.length > max ) {
		return txt.slice( 0, max ) + ' ... ' ;
	} else {
		return txt ;
	}
}

// Remove duplicates from the array
function _uniq( arr ) {
	return arr.filter( ( elem, pos, arr ) => arr.indexOf( elem ) == pos ) ;
}

// Zip two or more arrays
function _zip(arr, ...arrs) {
	return arr.map((val, i) => arrs.reduce((a, arr) => [...a, arr[i]], [val])) ;
}

// Intersection of two arrays of strings
function _intersection( a, b ) {
	return a.filter( item => b.indexOf( item ) !== -1 )
}

// Union of two arrays of strings
function _union( a, b ) {
	return _uniq( a.concat( b ) ) ;
}

// Asymmetric difference of two arrays of strings
function _asymmetric( a, b ) {
	return a.filter( item => b.indexOf( item ) === -1 ) ;
}

// Symmetric difference of two arrays of strings
function _symmetric( a, b ) {
	return _asymmetric( a, b ).concat( _asymmetric( b, a ) ) ;
}

function _test_set( ) {
	const abc = [ 'a','b','c' ] ;
	const dbc = [ 'd','b','c' ] ;
	const xy  = [ 'x','y' ] ;
	const empty = [] ;
	console.log( '%s - %s = %s', abc, dbc, _symmetric( abc, dbc ) ) ;
	console.log( '%s + %s = %s', abc, dbc, _union( abc, dbc ) ) ;
	console.log( '%s * %s = %s', abc, dbc, _intersection( abc, dbc ) ) ;
	console.log( '%s - %s = %s', abc, xy, _symmetric( abc, xy ) ) ;
	console.log( '%s + %s = %s', abc, xy, _union( abc, xy ) ) ;
	console.log( '%s * %s = %s', abc, xy, _intersection( abc, xy ) ) ;
	console.log( '%s - %s = %s', abc, empty, _symmetric( abc, empty ) ) ;
	console.log( '%s + %s = %s', abc, empty, _union( abc, empty ) ) ;
	console.log( '%s * %s = %s', abc, empty, _intersection( abc, empty ) ) ;
	console.log( '%s - %s = %s', abc, abc, _symmetric( abc, abc ) ) ;
	console.log( '%s + %s = %s', abc, abc, _union( abc, abc ) ) ;
	console.log( '%s * %s = %s', abc, abc, _intersection( abc, abc ) ) ;
}

// Read text file
function _read_txt( filename ) {
	try {
		return fs.readFileSync( filename, 'utf8' ) ;
	} catch( error ) {
		console.error( 'cannot read file %s (%s)', filename, error.message ) ;
		process.exit( 1 ) ;
	}
}

// Write text file
function _write_txt( filename, txt ) {
	try {
                if( filename === '-' ) {
                        fs.writeSync( 1, txt ) ;
                        fs.fsyncSync( 1 ) ;
                } else {
                        fs.writeFileSync( filename, txt ) ;
                }
	} catch( error ) {
		console.error( 'cannot write file %s (%s)', filename, error.message ) ;
		process.exit( 1 ) ;
	}
}

// Parse the JSON text
function _parse_JSON( txt ) {
	try {
		return JSON.parse( txt ) ;
	} catch( error ) {
		console.error( 'cannot parse JSON (%s)', error.message ) ;
		process.exit( 1 ) ;
	}
}

// Read JSON file
function _read_JSON( filename ) {
	const txt = _read_txt( filename ) ;
	return _parse_JSON( txt ) ;
}

// Stringify a value
function stringify_value( data ) {
	if( Array.isArray( data ) &&
		typeof( data[ 0 ] ) === 'string' &&
		data.map( item => item.length ).reduce( ( accu, item) => accu + item, 0 ) > 150 ) {
		return JSON.stringify( data, null, '    ' ) ;
	} else {
		return JSON.stringify( data ) ;
	}
}

// Stringify the main data type
function stringify_data( data ) {
	const txt_list = Object
		.entries( data )
		.filter( item => typeof item[ 1 ] !== 'undefined' && item[ 1 ] !== '' )
		.map( item => '  ' + JSON.stringify( item[ 0 ] ) + ': ' + stringify_value( item[ 1 ] ) ) ;
	return '{\n' + txt_list.join( ',\n' ) + '\n}' ;
}

// Write JSON file
function _write_JSON( filename, json ) {
	try {
		const txt = '[' + json.map( item => stringify_data( item ) ).join( ',\n\n' ) + '\n]\n' ;
		if( filename === '-' ) {
			fs.writeSync( 1, txt ) ;
			fs.fsyncSync( 1 ) ;
		} else {
			fs.writeFileSync( filename, txt ) ;
		}
	} catch( error ) {
		console.error( 'cannot write JSON to %s (%s)', filename, error.message ) ;
		process.exit( 1 ) ;
	}
}

// List the units. (the word 'en' has been removed in the normalisation).
const split_list = [
	{ word: 'miljard',	value: 1000000000 },
	{ word: 'miljo',	value: 1000000 },
	{ word: 'honderd?duizd',value: 100000 }, // deal with typos
	{ word: 'de?uizd',	value: 1000 }, // deal with typos
	{ word: 'honderd?',	value: 100 } // deal with typos
] ;

// Evaluate a normalised number written in words.
function word2number_evaluate( str, zero_or_one ) {
	if( str.length === 0 ) {
		return zero_or_one ;
	}
	for( var i = 0; i < split_list.length; i++ ) {
		const word_list = str.split( new RegExp( split_list[ i ].word, 'i' ) ) ;
		if( word_list.length === 2 ) {
			// console.log( 'debug %s \'%s\' %s', split_list[ i ].word, str, JSON.stringify( word_list ) ) ;
			return word2number_evaluate( word_list[ 0 ], 1 ) * split_list[ i ].value + word2number_evaluate( word_list[ 1 ], 0 ) ;
		} else if( word_list.length != 1 ) {
			throw 'number error ' + split_list[ i ].word + ' \'' + str + '\' ' + JSON.stringify( word_list ) ;
		}
	}
	const number_list = str.split( /([0-9\.]*)/ )
		.filter( item => item.match( /^[0-9\.]*$/ ) ) ;
	// console.log( 'debug number \'%s\' %s', str, JSON.stringify( number_list ) ) ;
	if( number_list.length === 0 ) {
		return zero_or_one ;
	}
	const value = number_list.map( item => {
		const value = Number.parseFloat( item ) ;
		if( isNaN( value ) ) {
			throw 'number error NaN \'' + str + '\' ' + item ;
		} else {
			return value ;
		}
	} ).reduce( ( accu, item) => accu + item, 0 );
	return value ;
}

// Normalise and evaluate a number written in words.
function _word2number( str ) {
	const normalised_str = str
		.trim()
		.replace( /[,\.-]/g,		'' )
		.replace( /^nul$/g,		' 0 ' )
		.replace( /^ander *half$/g,	' 1.5 ' )
		.replace( /en *een *half/g,	' 0.5 ' )
		.replace( /hal(?:f|ve)/g,	' 0.5 ' )
		.replace( /elf/g,		' 11 ' )
		.replace( /twaalf/g,		' 12 ' )
		.replace( /dertien/g,		' 13 ' )
		.replace( /veertien/g,		' 14 ' )
		.replace( /vijftien/g,		' 15 ' )
		.replace( /zestien/g,		' 16 ' )
		.replace( /zeventien/g,		' 17 ' )
		.replace( /achttien/g,		' 18 ' )
		.replace( /negentien/g,		' 19 ' )
		.replace( /tien/g,		' 10 ' )
		.replace( /zessentwintig/g,	' 26 ' ) // deal with typos
		.replace( /t?wintin?g/g,	' 20 ' ) // deal with typos
		.replace( /vijendertig/g,	' 35 ' ) // deal with typos
		.replace( /dertig/g,		' 30 ' )
		.replace( /v[ie]ertig/g,	' 40 ' ) // deal with typos
		.replace( /vijvenvijftig/g,	' 55 ' ) // deal with typos
		.replace( /vijft?ig/g,		' 50 ' ) // deal with typos
		.replace( /zestig/g,		' 60 ' )
		.replace( /zevenenzenventig/g,	' 77 ' ) // deal with typos
		.replace( /zeventig/g,		' 70 ' )
		.replace( /vierenachtig/g,	' 84 ' ) // deal with typos
		.replace( /negenachtig/g,	' 89 ' ) // deal with typos
		.replace( /tachtig/g,		' 80 ' )
		.replace( /negentig/g,		' 90 ' )
		.replace( /zessennegentig/g,	' 96 ' ) // deal with typos
		.replace( /tweee?n?/g,		' 2 ' )
		.replace( /driee?n?/g,		' 3 ' )
		.replace( /eene?n?/g,		' 1 ' )
		.replace( /viere?n?/g,		' 4 ' )
		.replace( /vijfe?n?/g,		' 5 ' )
		.replace( /zese?n?/g,		' 6 ' )
		.replace( /zevene?n?/g,		' 7 ' )
		.replace( /achte?n?/g,		' 8 ' )
		.replace( /negene?n?/g,		' 9 ' )
		.replace( /en/g,		'' )
		.replace( /tig/g,		'' ) // deal with typos
		.replace( /  */g,		' ' ) ;
	// console.log( 'debug \'%s\' -> \'%s\'', str, normalised_str ) ;
	if( normalised_str.match( /^ *[0-9]+ *$/ ) ) {
		return parseInt( normalised_str ) ;
	} else {
		return word2number_evaluate( normalised_str, 0 ) ;
	}
}

// List for testing
const test_word2number_list = [
	[0,	'nul'],
	[0.5,	'half'],
	[1,	'een'],
	[10,	'tien'],
	[10.5,	'tieneneenhalf'],
	[10.5,	'tienenhalf'],
	[100,	'eenhonderd'],
	[100,	'honderd'],
	[100.5,	'honderdeneenhalf'],
	[10000,	'tienduizend'],
	[100000,	'honderdduizend'],
	[100001,	'honderdduizendeen'],
	[101,	'honderdeen'],
	[101,	'honderdeneen'],
	[102,	'honderdtwee'],
	[10250,	'tienduizendtweehonderdvijftig'],
	[103,	'honderddrie'],
	[103,	'honderdendrie'],
	[104,	'eenhonderdvier'],
	[104,	'honderdvier'],
	[105,	'honderdenvijf'],
	[105,	'honderdvijf'],
	[10500,	'tienduizendvijfhonderd'],
	[106,	'honderdzes'],
	[107,	'eenhonderdzeven'],
	[107,	'honderdenzeven'],
	[107,	'honderdzeven'],
	[108,	'honderdacht'],
	[109,	'honderdnegen'],
	[11,	'elf'],
	[11.5,	'elfenhalf'],
	[110,	'honderdentien'],
	[110,	'honderdtien'],
	[1100,	'elfhonderd'],
	[11000,	'elfduizend'],
	[11000000,'elfmiljoen'],
	[111,	'honderdelf'],
	[112,	'honderdtwaalf'],
	[113,	'honderddertien'],
	[114,	'honderdenveertien'],
	[114,	'honderdveertien'],
	[115,	'honderdenvijftien'],
	[115,	'honderdvijftien'],
	[1158,	'elfhonderdenachtenvijftig'],
	[116,	'honderdzestien'],
	[117,	'honderdenzeventien'],
	[117,	'honderdzeventien'],
	[118,	'honderdachttien'],
	[118,	'honderdenachttien'],
	[119,	'honderdennegentien'],
	[119,	'honderdnegentien'],
	[119218.50,	'eenhonderd-en-negentien-duizend. tweehonderd-en-achttien-en-een-half'],
	[12,	'twaalf'],
	[12.5,	'twaalfenhalf'],
	[120,	'eenhonderd twintig'],
	[120,	'eenhonderdentwintig'],
	[120,	'eenhonderdtwintig'],
	[120,	'honderd en twintig'],
	[120,	'honderd twintig'],
	[120,	'honderdentwintig'],
	[120,	'honderdtwintig'],
	[120,	'honderdtwinting'],
	[120,	'honderdwintig'],
	[1200,	'twaalfhonderd'],
	[1201,	'twaalfhonderdeneen'],
	[122,	'honderdtweeentwintig'],
	[123,	'honderddrieentwintig'],
	[12340,	'twaalfduizenddriehonderdveertig'],
	[124,	'honderdvierentwintig'],
	[125,	'honderdvijfentwintig'],
	[126,	'honderdzesentwintig'],
	[127,	'honderdzevenentwintig'],
	[128,	'honderdachtentwintig'],
	[129,	'honderdnegenentwintig'],
	[130,	'honderddertig'],
	[131,	'honderdeenendertig'],
	[132,	'honderdtwee en dertig'],
	[134,	'honderdvierendertig'],
	[135,	'honderdvijfendertig'],
	[136,	'honderdzesendertig'],
	[137,	'honderdzevenendertig'],
	[138,	'honderdachtendertig'],
	[14,	'veertien'],
	[14.5,	'veertienenhalf'],
	[140,	'honderdenveertig'],
	[140,	'honderdveertig'],
	[141,	'honderdeenenveertig'],
	[1411,	'veertienhonderdenelf'],
	[143,	'honderddrieenveertig'],
	[144,	'honderdvierenveertig'],
	[145,	'honderdvijfenveertig'],
	[146,	'honderdzesenveertig'],
	[147,	'honderdzevenenveertig'],
	[148,	'eenhonderdachtenveertig'],
	[148,	'honderdachtenveertig'],
	[149,	'honderdnegenenveertig'],
	[15,	'vijftien'],
	[150,	'eenhonderdvijftig'],
	[150,	'honderdenvijftig'],
	[150,	'honderdvijfig'],
	[150,	'honderdvijftig'],
	[150,	'honderdvijftig'],
	[1500,	'vijftienhonderd'],
	[150000,	'honderdvijftigduizend'],
	[151,	'honderdeenenvijftig'],
	[154,	'honderdvierenvijftig'],
	[155,	'honderdenvijfenvijftig'],
	[155,	'honderdvijfenvijftig'],
	[156,	'honderdzesenvijftig'],
	[157,	'honderdzevenenvijftig'],
	[157,	'honderdzevenvijftig'],
	[158,	'honderdachtenvijftig'],
	[160,	'eenhonderdenzestig'],
	[160,	'honderdenzestig'],
	[160,	'honderdzestig'],
	[164,	'honderdenvierenzestig'],
	[164,	'honderdvierenzestig'],
	[165,	'eenhonderdvijfenzestig'],
	[165,	'honderdvijfenzestig'],
	[166,	'honderdzesenzestig'],
	[167,	'honderdzevenenzestig'],
	[16700,	'zestienduizendzevenhonderd'],
	[168,	'honderdachtenzestig'],
	[168,	'honderdenachtenzestig'],
	[169,	'honderdnegenenzestig'],
	[17,	'zeventien'],
	[170,	'honderdzeventig'],
	[170,	'thonderdzeventig'],
	[171,	'honderdeenenzeventig'],
	[174,	'honderdvierenzeventig'],
	[175,	'honderdvijfenzeventig'],
	[176,	'honderdzesenzeventig'],
	[1765,	'zeventienhonderdvijfenzestig'],
	[177,	'honderdzevenenzeventig'],
	[178,	'honderdachtenzeventig'],
	[178,	'honderdenachtenzeventig'],
	[179,	'honderdnegenenzeventig'],
	[18,	'achttien'],
	[180,	'eenhonderdentachtig'],
	[180,	'eenhonderdtachtig'],
	[180,	'honderdentachtig'],
	[180,	'honderdtachtig'],
	[181,	'honderdeenentachtig'],
	[1835,	'achttienhonderdenvijfendertig'],
	[184,	'honderdvierentachtig'],
	[185,	'honderdenvijfentachtig'],
	[185,	'honderdvijfentachtig'],
	[185,	'honderdvijfentachtigtig'],
	[186,	'honderdzesentachtig'],
	[187,	'eenhonderdenzevenentachtig'],
	[187,	'honderdzevenentachtig'],
	[188,	'eenhonderdenachtentachtig'],
	[188,	'honderdachtentachtig'],
	[189,	'honderdnegenentachtig'],
	[190,	'honderdnegentig'],
	[191,	'honderdeenennegentig'],
	[193,	'honderdrieennegentig'],
	[194,	'honderdvierennegentig'],
	[196,	'eenhonderdenzesennegentig'],
	[196,	'honderdzesennegentig'],
	[197,	'honderdzevenennegentig'],
	[198,	'honderdachtennegentig'],
	[199,	'honderdnegenennegentig'],
	[2,	'twee'],
	[20,	'twintig'],
	[200,	'tweehonderd'],
	[20000,	'twintigduizend'],
	[203,	'tweehonderddrie'],
	[204,	'tweehonderdvier'],
	[205,	'tweehonderdvijf'],
	[206,	'tweehonderdenzes'],
	[207,	'tweehonderdenzeven'],
	[207,	'tweehonderdzeven'],
	[208,	'tweehonderdacht'],
	[210,	'tweehonderdentien'],
	[210,	'tweehonderdtien'],
	[211,	'tweehonderdelf'],
	[213,	'tweehonderddertien'],
	[214,	'tweehonderdenveertien'],
	[214,	'tweehonderdveertien'],
	[2150,	'eenentwintighonderdvijftig'],
	[216,	'tweehonderdzestien'],
	[217,	'tweehonderdzeventien'],
	[218,	'tweehonderdachttien'],
	[219,	'tweehonderdnegentien'],
	[22,	'tweeentwintig'],
	[220,	'tweehonderdtwintig'],
	[221,	'tweehonderdeenentwintig'],
	[222,	'tweehonderdtweeentwintig'],
	[223,	'tweehonderd-drieentwintig'],
	[223,	'tweehonderddrieentwintig'],
	[224,	'tweehonderdvierentwintig'],
	[226,	'tweehonderdzesentwintig'],
	[227,	'tweehonderdzevenentwintig'],
	[228,	'tweehonderdachtentwintig'],
	[228,	'tweehonderdenachtentwintig'],
	[229,	'tweehonderdennegenentwintig'],
	[229,	'tweehonderdnegenentwintig'],
	[230,	'tweehonderddertig'],
	[231,	'tweehonderdeenendertig'],
	[234,	'tweehonderdenvierendertig'],
	[234,	'tweehonderdvierendertig'],
	[235,	'tweehonderdvijfendertig'],
	[236,	'tweehonderdzesendertig'],
	[237,	'tweehonderdenzevenendertig'],
	[237,	'tweehonderdzevenendertig'],
	[238,	'tweehonderdachtendertig'],
	[239,	'tweehonderdnegenendertig'],
	[240,	'tweehonderd en veertig'],
	[240,	'tweehonderd veertig'],
	[240,	'tweehonderdenveertig'],
	[240,	'tweehonderdenviertig'],
	[240,	'tweehonderdveertig'],
	[240,	'tweehonderveertig'],
	[24000,	'vierentwintigduizend'],
	[241,	'tweehonderdeenenveertig'],
	[243,	'tweehonderddrieenveertig'],
	[244,	'tweehonderdvierenveertig'],
	[245,	'tweehonderdvijfenveertig'],
	[247,	'tweehonderdzevenenveertig'],
	[25,	'vijfentwintig'],
	[250,	'tweehonderd en vijftig'],
	[250,	'tweehonderdenvijftig'],
	[250,	'tweehonderdvijftig'],
	[2500,	'tweeduizendvijfhonderd'],
	[2500,	'vijfentwintighonderd'],
	[251,	'tweehonderdeenenvijftig'],
	[254,	'tweehonderdvierenvijftig'],
	[255,	'tweehonderdvijfenvijftig'],
	[256,	'tweehonderdzesenvijftig'],
	[258,	'tweehonderdachtenvijftig'],
	[26,	'zesentwintig'],
	[26.5,	'zesentwintigenhalf'],
	[260,	'tweehonderdzestig'],
	[26000,	'zesentwintigduizend'],
	[261,	'tweehonderdeenenzestig'],
	[262,	'tweehonderdtweeenzestig'],
	[264,	'tweehonderdvierenzestig'],
	[265,	'tweehonderdvijfenzestig'],
	[266,	'tweehonderdenzesenzestig'],
	[266,	'tweehonderdzesenzestig'],
	[267,	'tweehonderdzevenenzestig'],
	[26700,	'zesentwintigduizendzevenhonderd'],
	[268,	'tweehonderdachtenzestig'],
	[269,	'tweehonderdnegenenzestig'],
	[27,	'zevenentwintig'],
	[270,	'tweehonderdenzeventig'],
	[270,	'tweehonderdzeventig'],
	[274,	'tweehonderdvierenzeventig'],
	[275,	'tweehonderdvijfenzeventig'],
	[276,	'tweehonderdzesenzeventig'],
	[277,	'tweehonderdzevenenzeventig'],
	[278,	'tweehonderdachtenzeventig'],
	[279,	'tweehonderdennegenenzeventig'],
	[28,	'achtentwintig'],
	[280,	'tweehonderdtachtig'],
	[2801,	'achtentwintighonderdeneen'],
	[281,	'tweehonderdeenentachtig'],
	[285,	'tweehonderdvijfentachtig'],
	[2850,	'achtentwintighonderdenvijftig'],
	[287,	'tweehonderdzevenentachtig'],
	[290,	'tweehonderdnegentig'],
	[29000,	'negenentwintigduizend'],
	[295,	'tweehonderdvijfennegentig'],
	[297,	'tweehonderdenzevenennegentig'],
	[298,	'tweehonderdachtennegentig'],
	[299,	'tweehonderdnegenennegentig'],
	[3,	'drie'],
	[3.5,	'drieenhalf'],
	[3.5,	'drieenhalve'],
	[30,	'dertig'],
	[30,	'twintig a dertig'],
	[300,	'driehonderd'],
	[300000,	'driehonderdduizend'],
	[300000,'driehonderdduizend'],
	[304,	'driehonderdvier'],
	[306,	'driehonderdzes'],
	[307,	'driehonderdzeven'],
	[309,	'driehonderdnegen'],
	[312,	'driehonderdtwaalf'],
	[313,	'driehonderddertien'],
	[315,	'driehonderdenvijftien'],
	[315,	'driehonderdvijftien'],
	[317,	'driehonderdzeventien'],
	[318,	'driehonderdenachttien'],
	[319,	'driehonderdnegentien'],
	[320,	'driehonderdtwintig'],
	[32000,	'tweeendertigduizend'],
	[325,	'driehonderdvijfentwintig'],
	[326,	'driehonderdzesentwintig'],
	[327,	'driehonderdzevenentwintig'],
	[328,	'driehonderdachtentwintig'],
	[329,	'driehonderdnegenentwintig'],
	[335,	'driehonderdvijfendertig'],
	[3357,	'drieduizenddriehonderdzevenenvijftig'],
	[338,	'driehonderdachtendertig'],
	[344,	'driehonderdvierenveertig'],
	[345,	'driehonderdvijfenveertig'],
	[346,	'driehonderdzesenveertig'],
	[348,	'driehonderdachtenveertig'],
	[350,	'driehonderdvijftig'],
	[35000,	'vijfendertigduizend'],
	[351,	'driehonderdeenenvijftig'],
	[3530,	'drieduizendvijfhonderdendertig'],
	[354,	'driehonderdvierenvijftig'],
	[357,	'driehonderdzevenenvijftig'],
	[360,	'driehonderdenzestig'],
	[360,	'driehonderdzestig'],
	[361,	'driehonderdeenenzestig'],
	[364,	'driehonderdvierenzestig'],
	[365,	'driehonderdenvijfenzestig'],
	[365,	'driehonderdvijfenzestig'],
	[367,	'driehonderdzevenenzestig'],
	[368,	'driehonderdachtenzestig'],
	[37.5,	'zeven en dertig en een half'],
	[370,	'driehonderdzeventig'],
	[375,	'zeven en dertig vijf'],
	[377,	'driehonderdenzevenenzeventig'],
	[377,	'driehonderdzevenenzeventig'],
	[380,	'driehonderdtachtig'],
	[381,	'driehonderdeenentachtig'],
	[39,	'negenendertig'],
	[390,	'driehonderdnegentig'],
	[3980,	'drieduizendnegenhonderdentachtig'],
	[4,	'vier'],
	[40,	'veertig'],
	[400,	'vierhonderd'],
	[40000,	'veertigduizend'],
	[404,	'vierhonderdvier'],
	[413,	'vierhonderddertien'],
	[42,	'tweeenveertig'],
	[420,	'vierhonderdtwintig'],
	[425,	'vierhonderdvijfentwintig'],
	[426,	'vierhonderdenzesentwintig'],
	[426,	'vierhonderdzesentwintig'],
	[427,	'vierhonderdzevenentwintig'],
	[429,	'vierhonderdnegenentwintig'],
	[43,	'drieenveertig'],
	[430,	'vierhonderddertig'],
	[435,	'vierhonderdvijfendertig'],
	[436,	'vierhonderdzesendertig'],
	[438,	'vierhonderdachtendertig'],
	[439,	'vierhonderdnegenendertig'],
	[44,	'vierenveertig'],
	[44.5,	'vierenveertigenhalf'],
	[440,	'vierhonderdveertig'],
	[45,	'vijfenveertig'],
	[450,	'vierhonderdenvijftig'],
	[450,	'vierhonderdvijftig'],
	[46,	'zesenveertig'],
	[467,	'vierhonderdzevenenzestig'],
	[469,	'vierhonderdnegenzestig'],
	[475,	'vierhonderdvijfenzeventig'],
	[480,	'vierhonderdtachtig'],
	[487,	'vierhonderdenzevenentachtig'],
	[487,	'vierhonderdzevenentachtig'],
	[490,	'vierhonderdnegentig'],
	[494,	'vierhonderdenvierennegentig'],
	[497,	'vierhonderdzevenennegentig'],
	[5,	'vijf'],
	[50,	'vijftig'],
	[500,	'vijfhonderd'],
	[5000,	'vijfduizend'],
	[51,	'eenenvijftig'],
	[510,	'vijfhonderdentien'],
	[511,	'vijfhonderdelf'],
	[518,	'vijfhonderdachttien'],
	[519,	'vijfhonderdnegentien'],
	[521,	'vijfhonderdeenentwintig'],
	[534,	'vijfhonderdvierendertig'],
	[536,	'vijfhonderdzesendertig'],
	[540,	'vijfhonderdveertig'],
	[541,	'vijfhonderdeenenveertig'],
	[545,	'vijfhonderdvijfenveertig'],
	[549,	'vijfhonderdnegenenveertig'],
	[550,	'vijfhonderdvijftig'],
	[5555.5,'vijfduizendvijfhonderdvijfenvijftigenhalf'],
	[563,	'vijfhonderddrieenzestig'],
	[565,	'vijfhonderdvijfenzestig'],
	[57,	'zevenenvijftig'],
	[5700,	'zevenenvijftighonderd'],
	[573,	'vijfhonderden drieenzeventig'],
	[574,	'vijfhonderdvierenzeventig'],
	[575,	'vijfhonderdvijfenzeventig'],
	[58,	'achtenvijftig'],
	[580,	'vijfhonderdtachtig'],
	[58590,	'achtenvijftigduizendvijfhonderdnegentig'],
	[59,	'negenenvijftig'],
	[590,	'vijfhonderdnegentig'],
	[6,	'zes'],
	[60,	'zestig'],
	[600,	'zeshonderd'],
	[612,	'zeshonderdtwaalf'],
	[624,	'zeshonderdvierentwintig'],
	[654,	'zeshonderdvierenvijftig'],
	[658,	'zeshonderdachtenvijftig'],
	[66,	'zesenzestig'],
	[6600,	'zesduizendzeshonderd'],
	[6667.5,'zesduizendzeshonderdzevenenzestigeneenhalf'],
	[6667.50,	'zesduizendzeshonderdzevenenzestigeneenhalf'],
	[688,	'zeshonderdenachtentachtig'],
	[7,	'zeven'],
	[7.5,	'zevenenhalf'],
	[70,	'zeventig'],
	[70.5,	'zeventigenhalf'],
	[700,	'zevenhonderd'],
	[711,	'zevenhonderdelf'],
	[72,	'tweeenzeventig'],
	[720,	'zevenhonderdtwintig'],
	[730,	'zevenhonderddertig'],
	[75,	'vijfenzeventig'],
	[750,	'zevenhonderdenvijftig'],
	[750,	'zevenhonderdvijftig'],
	[7500,	'vijfenzeventighonderd'],
	[770,	'zevenhonderdzeventig'],
	[79,	'negenenzeventig'],
	[8,	'acht'],
	[8.5,	'achtenhalf'],
	[80,	'tachtig'],
	[802,	'achthonderdtwee'],
	[82,	'tweeentachtig'],
	[84,	'vierentachtig'],
	[85,	'vijfentachtig'],
	[8500,	'achtduizendvijfhonderd'],
	[850000,	'achthonderdvijftigduizend'],
	[9,	'negen'],
	[90,	'negentig'],
	[900,	'negenhonderd'],
	[905,	'negenhonderdvijf'],
	[91,	'eenennegentig'],
	[92,	'tweeennegentig'],
	[934,	'negenhonderdvierendertig'],
	[960,	'negenhonderdzestig']
] ;

function _test_word2number() {
	test_word2number_list.map( item => {
		const value = item[ 0 ];
		var check ;
		try {
			check = _word2number( item[ 1 ] ) ;
		} catch( e ) {
			console.log( '%s', JSON.stringify( e ) ) ;
		}
		if( value !== check ) {
			console.log( '%s, %f, %s', item[ 1 ], value, check ) ;
		}
	} ) ;
}

// Convert time units to hours.
function _unit2hours( value, unit ) {
	if( unit.match( /(?:uur|uren)/i ) ) {
		return value ;
	} else if( unit.match( /(?:dag|dagen)/i ) ) {
		return value * 24 ;
	} else if( unit.match( /(?:week|weken)/i ) ) {
		return value * ( 7 * 24 ) ;
	} else if( unit.match( /(?:maand|maanden)/i ) ) {
		return value * ( 30 * 24 ) ;
	} else if( unit.match( /(?:jaar|jaren)/i ) ) {
		return value * ( 360 * 24 ) ;
	} else if( unit.match( /levenslange?/i ) ) {
		return value * ( 30 * 360 * 24 ) ;
	} else {
		return undefined ;
	}
}

// Convert hours to time units.
function _hours2unit( value, unit ) {
	if( unit.match( /(?:uur|uren)/i ) ) {
		return value ;
	} else if( unit.match( /(?:dag|dagen)/i ) ) {
		return value / 24 ;
	} else if( unit.match( /(?:week|weken)/i ) ) {
		return value / ( 7 * 24 ) ;
	} else if( unit.match( /(?:maand|maanden)/i ) ) {
		return value / ( 30 * 24 ) ;
	} else if( unit.match( /(?:jaar|jaren)/i ) ) {
		return value / ( 360 * 24 ) ;
	} else if( unit.match( /levenslange?/i ) ) {
		return value / ( 30 * 360 * 24 ) ;
	} else {
		return undefined ;
	}
}

// List of units
const unit_list = [
	'uur',
	'dag',
	'week',
	'maand',
	'jaar',
	'levenslang'
] ;

function _test_hours() {
	unit_list.map( unit => {
		for( var x_value = 0; x_value <= 1000; x_value++ ) {
			const hours = _unit2hours( x_value, unit ) ;
			const y_value = _hours2unit( hours, unit ) ;
			if( x_value !== y_value ) {
				console.log( '%d != %d (unit %s hours %f)', x_value, y_value, unit, hours ) ;
			}
		}
	} ) ;
}

// Normalise time units.
function _normalise_unit( unit ) {
	var result ;
	if( unit.match( /(?:uur|uren)/i ) ) {
		result = 'uur' ;
	} else if( unit.match( /(?:dag|dagen)/i ) ) {
		result = 'dag' ;
	} else if( unit.match( /(?:week|weken)/i ) ) {
		result = 'week' ;
	} else if( unit.match( /(?:maand|maanden)/i ) ) {
		result = 'maand' ;
	} else if( unit.match( /(?:jaar|jaren)/i ) ) {
		result = 'jaar' ;
	} else if( unit.match( /levenslange?/i ) ) {
		result = 'levenslang' ;
	}
	return result ;
}

module.exports = {
	truncate: _truncate,
	unit2hours: _unit2hours,
	hours2unit: _hours2unit,
	normalise_unit: _normalise_unit,
	uniq: _uniq,
	zip: _zip,
	intersection: _intersection,
	union: _union,
	asymmetric: _asymmetric,
	symmetric: _symmetric,
	read_txt: _read_txt,
	write_txt: _write_txt,
	parse_JSON: _parse_JSON,
	read_JSON: _read_JSON,
	write_JSON: _write_JSON,
	word2number: _word2number,
	test_set: _test_set,
	test_word2number: _test_word2number,
	test_hours: _test_hours
} ;
